#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .implicit_bodyforce_treatment import implicit_bodyforce_treatment
from .velocity_formulation import velocity_formulation
from .physical_velocity_formulation import physical_velocity_formulation
from .disable_rhie_chow_flux import disable_rhie_chow_flux
from .presto_pressure_scheme import presto_pressure_scheme
from .first_to_second_order_blending_1 import first_to_second_order_blending
from .alternate_diffusion_for_porous_region_solids import alternate_diffusion_for_porous_region_solids
class numerics(Group):
    """
    'numerics' child.
    """

    fluent_name = "numerics"

    child_names = \
        ['implicit_bodyforce_treatment', 'velocity_formulation',
         'physical_velocity_formulation', 'disable_rhie_chow_flux',
         'presto_pressure_scheme', 'first_to_second_order_blending',
         'alternate_diffusion_for_porous_region_solids']

    implicit_bodyforce_treatment: implicit_bodyforce_treatment = implicit_bodyforce_treatment
    """
    implicit_bodyforce_treatment child of numerics.
    """
    velocity_formulation: velocity_formulation = velocity_formulation
    """
    velocity_formulation child of numerics.
    """
    physical_velocity_formulation: physical_velocity_formulation = physical_velocity_formulation
    """
    physical_velocity_formulation child of numerics.
    """
    disable_rhie_chow_flux: disable_rhie_chow_flux = disable_rhie_chow_flux
    """
    disable_rhie_chow_flux child of numerics.
    """
    presto_pressure_scheme: presto_pressure_scheme = presto_pressure_scheme
    """
    presto_pressure_scheme child of numerics.
    """
    first_to_second_order_blending: first_to_second_order_blending = first_to_second_order_blending
    """
    first_to_second_order_blending child of numerics.
    """
    alternate_diffusion_for_porous_region_solids: alternate_diffusion_for_porous_region_solids = alternate_diffusion_for_porous_region_solids
    """
    alternate_diffusion_for_porous_region_solids child of numerics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class levelset_auto_init(Command):
    """
    'levelset_auto_init' command.
    """

    fluent_name = "levelset-auto-init"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .process_count import process_count
from .host_name import host_name
class helper_session_setup(Group):
    """
    Setup helper session for multidomain conjugate heat transfer.
    """

    fluent_name = "helper-session-setup"

    child_names = \
        ['process_count', 'host_name']

    process_count: process_count = process_count
    """
    process_count child of helper_session_setup.
    """
    host_name: host_name = host_name
    """
    host_name child of helper_session_setup.
    """



"""A package providing job scheduler support."""

import os
import socket
import sys

from ansys.fluent.core.scheduler.load_machines import load_machines  # noqa: F401
from ansys.fluent.core.scheduler.machine_list import MachineList

_ncoresOpt = "-t%n%"
_machinesOpt = " -cnf=%machineList%"
_procSep = ":"
_machineSep = ","


def build_parallel_options(machine_list: MachineList) -> str:
    """Constructs Fluent's parallel arguments given a list of machines.

    Parameters
    ----------
    machine_list : MachineList
        List of machines obtained by calling `load_machines`.

    Notes
    -----
    When running serial no options are passed back to the caller as Fluent can
    be started without additional arguments in that case.

    If the parallel options are being built on the same machine as Fluent is run
    on, and it's local parallel, then the -cnf argument is not constructed.  On
    Windows HPC the job scheduler returns hostnames as upper case but the socket
    module may return lower case.
    """
    parOpt = ""
    if sys.platform == "win32" and "CCP_NODES" in os.environ:
        localParallel = (
            socket.gethostname().upper() == machine_list[0].host_name.upper()
        )
    else:
        localParallel = socket.gethostname() == machine_list[0].host_name
    if machine_list.num_machines == 1 and localParallel:
        if machine_list.number_of_cores > 1:
            parOpt = _ncoresOpt.replace("%n%", str(machine_list.number_of_cores))
    else:
        parOpt = _ncoresOpt.replace("%n%", str(machine_list.number_of_cores))
        cnfList = (
            machine_list[0].host_name + _procSep + str(machine_list[0].number_of_cores)
        )
        for m in range(1, len(machine_list)):
            cnfList += (
                _machineSep
                + machine_list[m].host_name
                + _procSep
                + str(machine_list[m].number_of_cores)
            )
        parOpt += _machinesOpt.replace("%machineList%", cnfList)
    return parOpt



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class turbulence_multiphase_models(String):
    """
    'turbulence_multiphase_models' child.
    """

    fluent_name = "turbulence-multiphase-models"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class num_of_density_smoothing(Integer):
    """
    Set number of density smoothings.
    """

    fluent_name = "num-of-density-smoothing"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class radius_ratio(Real):
    """
    The span-wise distance of blade section from rotor origin over rotor tip radius (r/R).
    """

    fluent_name = "radius-ratio"




"""Module providing asynchronous execution functionality."""

from concurrent.futures import ThreadPoolExecutor
import functools
from typing import Callable


def asynchronous(f: Callable) -> Callable:
    """Use for decorating functions that are to execute asynchronously. The
    decorated function returns a `future`_ object. Calling `result()`_ on the
    future object synchronizes the function execution.

    Examples
    --------
    >>> # asynchronous execution using @asynchronous decorator
    >>> @asynchronous
    ... def asynchronous_solve(session, number_of_iterations):
    ...     session.solver.tui.solve.iterate(number_of_iterations)
    >>> asynchronous_solve(session1, 100)

    >>> # using the asynchronous function directly
    >>> asynchronous(session2.solver.tui.solve.iterate)(100)

    >>> # synchronous execution of above 2 calls
    >>> asynchronous_solve(session1, 100).result()
    >>> asynchronous(session2.solver.tui.solve.iterate)(100).result()

    .. _Future: https://docs.python.org/3/library/asyncio-future.html#future-object  # noqa: E501
    .. _result(): https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.result  # noqa: E501
    """

    @functools.wraps(f)
    def func(*args, **kwargs) -> Callable:
        return ThreadPoolExecutor(max_workers=1).submit(f, *args, **kwargs)

    return func



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .runge_kutta import runge_kutta
class fast_transient_settings(Group):
    """
    Enter the fast transient settings menu.
    """

    fluent_name = "fast-transient-settings"

    child_names = \
        ['runge_kutta']

    runge_kutta: runge_kutta = runge_kutta
    """
    runge_kutta child of fast_transient_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .options_5 import options
from .edge_type import edge_type
from .shrink_factor import shrink_factor
from .surfaces_list import surfaces_list
from .coloring_1 import coloring
from .display_state_name import display_state_name
from .physics import physics
from .geometry_3 import geometry
from .surfaces import surfaces
from .display_2 import display
class mesh_child(Group):
    """
    'child_object_type' of mesh.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'options', 'edge_type', 'shrink_factor', 'surfaces_list',
         'coloring', 'display_state_name', 'physics', 'geometry', 'surfaces']

    name: name = name
    """
    name child of mesh_child.
    """
    options: options = options
    """
    options child of mesh_child.
    """
    edge_type: edge_type = edge_type
    """
    edge_type child of mesh_child.
    """
    shrink_factor: shrink_factor = shrink_factor
    """
    shrink_factor child of mesh_child.
    """
    surfaces_list: surfaces_list = surfaces_list
    """
    surfaces_list child of mesh_child.
    """
    coloring: coloring = coloring
    """
    coloring child of mesh_child.
    """
    display_state_name: display_state_name = display_state_name
    """
    display_state_name child of mesh_child.
    """
    physics: physics = physics
    """
    physics child of mesh_child.
    """
    geometry: geometry = geometry
    """
    geometry child of mesh_child.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of mesh_child.
    """
    command_names = \
        ['display']

    display: display = display
    """
    display command of mesh_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .allow_repair_at_boundaries import allow_repair_at_boundaries
from .include_local_polyhedra_conversion_in_repair import include_local_polyhedra_conversion_in_repair
from .repair_poor_elements import repair_poor_elements
from .improve_quality import improve_quality
from .repair import repair
from .repair_face_handedness import repair_face_handedness
from .repair_face_node_order import repair_face_node_order
from .repair_wall_distance import repair_wall_distance
class repair_improve(Group):
    """
    Enter the repair and improve quality menu.
    """

    fluent_name = "repair-improve"

    child_names = \
        ['allow_repair_at_boundaries',
         'include_local_polyhedra_conversion_in_repair']

    allow_repair_at_boundaries: allow_repair_at_boundaries = allow_repair_at_boundaries
    """
    allow_repair_at_boundaries child of repair_improve.
    """
    include_local_polyhedra_conversion_in_repair: include_local_polyhedra_conversion_in_repair = include_local_polyhedra_conversion_in_repair
    """
    include_local_polyhedra_conversion_in_repair child of repair_improve.
    """
    command_names = \
        ['repair_poor_elements', 'improve_quality', 'repair',
         'repair_face_handedness', 'repair_face_node_order',
         'repair_wall_distance']

    repair_poor_elements: repair_poor_elements = repair_poor_elements
    """
    repair_poor_elements command of repair_improve.
    """
    improve_quality: improve_quality = improve_quality
    """
    improve_quality command of repair_improve.
    """
    repair: repair = repair
    """
    repair command of repair_improve.
    """
    repair_face_handedness: repair_face_handedness = repair_face_handedness
    """
    repair_face_handedness command of repair_improve.
    """
    repair_face_node_order: repair_face_node_order = repair_face_node_order
    """
    repair_face_node_order command of repair_improve.
    """
    repair_wall_distance: repair_wall_distance = repair_wall_distance
    """
    repair_wall_distance command of repair_improve.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class face_pressure_calculation_method(String):
    """
    Set face pressure calculation method for corrector step .
    """

    fluent_name = "face-pressure-calculation-method"




def fix_definition_list_in_class_doc(doc: str):
    old_lines = doc.splitlines(keepends=True)
    new_lines = []
    for i, line in enumerate(old_lines):
        if line.strip().startswith("-") and not line.strip().startswith("--"):
            if i == 0:
                new_lines.append("\n")
                new_lines.append(line)
            elif i == len(old_lines) - 1:
                new_lines.append(line)
                new_lines.append("\n")
            else:
                prev_line = old_lines[i - 1].strip()
                if prev_line and not prev_line.startswith("-"):
                    new_lines.append("\n")
                new_lines.append(line)
                next_line = old_lines[i + 1].strip()
                if next_line and not next_line.startswith("-"):
                    new_lines.append("\n")
        else:
            new_lines.append(line)
    return "".join(new_lines)


def fix_settings_doc(doc: str):
    return fix_definition_list_in_class_doc(doc)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .schnerr_evap_coeff import schnerr_evap_coeff
from .schnerr_cond_coeff import schnerr_cond_coeff
from .max_vapor_pressure_ratio import max_vapor_pressure_ratio
from .min_vapor_pressure import min_vapor_pressure
from .display_clipped_pressure import display_clipped_pressure
from .turbulent_diffusion import turbulent_diffusion
from .old_treatment_for_turbulent_diffusion import old_treatment_for_turbulent_diffusion
class cavitation(Group):
    """
    Cavitation numerics options menu.
    """

    fluent_name = "cavitation"

    child_names = \
        ['schnerr_evap_coeff', 'schnerr_cond_coeff',
         'max_vapor_pressure_ratio', 'min_vapor_pressure',
         'display_clipped_pressure', 'turbulent_diffusion',
         'old_treatment_for_turbulent_diffusion']

    schnerr_evap_coeff: schnerr_evap_coeff = schnerr_evap_coeff
    """
    schnerr_evap_coeff child of cavitation.
    """
    schnerr_cond_coeff: schnerr_cond_coeff = schnerr_cond_coeff
    """
    schnerr_cond_coeff child of cavitation.
    """
    max_vapor_pressure_ratio: max_vapor_pressure_ratio = max_vapor_pressure_ratio
    """
    max_vapor_pressure_ratio child of cavitation.
    """
    min_vapor_pressure: min_vapor_pressure = min_vapor_pressure
    """
    min_vapor_pressure child of cavitation.
    """
    display_clipped_pressure: display_clipped_pressure = display_clipped_pressure
    """
    display_clipped_pressure child of cavitation.
    """
    turbulent_diffusion: turbulent_diffusion = turbulent_diffusion
    """
    turbulent_diffusion child of cavitation.
    """
    old_treatment_for_turbulent_diffusion: old_treatment_for_turbulent_diffusion = old_treatment_for_turbulent_diffusion
    """
    old_treatment_for_turbulent_diffusion child of cavitation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class volumetric_synthetic_turbulence_generator_option(String):
    """
    'volumetric_synthetic_turbulence_generator_option' child.
    """

    fluent_name = "volumetric-synthetic-turbulence-generator-option"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .initial_time_steps import initial_time_steps
from .initial_outer_iter import initial_outer_iter
class initial_outer_iterations(Group):
    """
    'initial_outer_iterations' child.
    """

    fluent_name = "initial-outer-iterations"

    child_names = \
        ['initial_time_steps', 'initial_outer_iter']

    initial_time_steps: initial_time_steps = initial_time_steps
    """
    initial_time_steps child of initial_outer_iterations.
    """
    initial_outer_iter: initial_outer_iter = initial_outer_iter
    """
    initial_outer_iter child of initial_outer_iterations.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class is_not_a_rans_les_interface(Boolean):
    """
    'is_not_a_rans_les_interface' child.
    """

    fluent_name = "is-not-a-rans-les-interface"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .controls import controls
from .methods_1 import methods
from .report_definitions import report_definitions
from .initialization import initialization
from .run_calculation import run_calculation
class solution(Group):
    """
    'solution' child.
    """

    fluent_name = "solution"

    child_names = \
        ['controls', 'methods', 'report_definitions', 'initialization',
         'run_calculation']

    controls: controls = controls
    """
    controls child of solution.
    """
    methods: methods = methods
    """
    methods child of solution.
    """
    report_definitions: report_definitions = report_definitions
    """
    report_definitions child of solution.
    """
    initialization: initialization = initialization
    """
    initialization child of solution.
    """
    run_calculation: run_calculation = run_calculation
    """
    run_calculation child of solution.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enabled_2 import enabled
from .set_2 import set
class laplace_smoothing(Group):
    """
    'laplace_smoothing' child.
    """

    fluent_name = "laplace-smoothing"

    child_names = \
        ['enabled', 'set']

    enabled: enabled = enabled
    """
    enabled child of laplace_smoothing.
    """
    set: set = set
    """
    set child of laplace_smoothing.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis_begin import axis_begin
from .axis_end import axis_end
from .radius import radius
from .inside import inside
from .create_volume_surface import create_volume_surface
class cylinder(Group):
    """
    'cylinder' child.
    """

    fluent_name = "cylinder"

    child_names = \
        ['axis_begin', 'axis_end', 'radius', 'inside',
         'create_volume_surface']

    axis_begin: axis_begin = axis_begin
    """
    axis_begin child of cylinder.
    """
    axis_end: axis_end = axis_end
    """
    axis_end child of cylinder.
    """
    radius: radius = radius
    """
    radius child of cylinder.
    """
    inside: inside = inside
    """
    inside child of cylinder.
    """
    create_volume_surface: create_volume_surface = create_volume_surface
    """
    create_volume_surface child of cylinder.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class recommended_defaults_for_existing_cases(Boolean):
    """
    Activate multiphase defaults for loaded case.
    """

    fluent_name = "recommended-defaults-for-existing-cases"




"""Wrapper over the monitor grpc service of Fluent."""

from google.protobuf.json_format import MessageToDict
import grpc

from ansys.api.fluent.v0 import monitor_pb2 as MonitorModule
from ansys.api.fluent.v0 import monitor_pb2_grpc as MonitorGrpcModule
from ansys.fluent.core.services.streaming import StreamingService


class MonitorsService(StreamingService):
    """Class wrapping the monitor gRPC service of Fluent."""

    def __init__(self, channel: grpc.Channel, metadata):
        self._stub = MonitorGrpcModule.MonitorStub(channel)
        self._metadata = metadata
        super().__init__(
            stub=self._stub,
            request=MonitorModule.StreamingRequest(),
            metadata=self._metadata,
        )

    def get_monitors_info(self) -> dict:
        """Get monitors information.

        Parameters
        ----------
        None

        Returns
        -------
        dict
            Dictionary containing the monitors information.
        """
        monitors_info = {}
        request = MonitorModule.GetMonitorsRequest()
        response = self._stub.GetMonitors(request, metadata=self._metadata)
        for monitor_set in response.monitorset:
            monitor_info = MessageToDict(monitor_set)
            monitors_info[monitor_set.name] = monitor_info
        return monitors_info



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class cfl_type(Integer):
    """
    Set CFL type 
    [1]Convective   [2]Convective-Diffusive   [3]Acoustic   [4]Flow.
    """

    fluent_name = "cfl-type"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
class list_properties(Command):
    """
    List the properties of a material in the database.
    
    Parameters
    ----------
        name : str
            'name' child.
    
    """

    fluent_name = "list-properties"

    argument_names = \
        ['name']

    name: name = name
    """
    name argument of list_properties.
    """



"""Wrapper to settings gRPC service of Fluent."""
import collections.abc
from typing import Any, List

import grpc

from ansys.api.fluent.v0 import settings_pb2 as SettingsModule
from ansys.api.fluent.v0 import settings_pb2_grpc as SettingsGrpcModule
from ansys.fluent.core.services.error_handler import catch_grpc_error
from ansys.fluent.core.services.interceptors import TracingInterceptor


class _SettingsServiceImpl:
    def __init__(self, channel: grpc.Channel, metadata):
        tracing_interceptor = TracingInterceptor()
        intercept_channel = grpc.intercept_channel(channel, tracing_interceptor)
        self.__stub = SettingsGrpcModule.SettingsStub(intercept_channel)
        self.__metadata = metadata

    @catch_grpc_error
    def set_var(self, request):
        return self.__stub.SetVar(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_var(self, request):
        return self.__stub.GetVar(request, metadata=self.__metadata)

    @catch_grpc_error
    def rename(self, request):
        return self.__stub.Rename(request, metadata=self.__metadata)

    @catch_grpc_error
    def create(self, request):
        return self.__stub.Create(request, metadata=self.__metadata)

    @catch_grpc_error
    def delete(self, request):
        return self.__stub.Delete(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_object_names(self, request):
        return self.__stub.GetObjectNames(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_list_size(self, request):
        return self.__stub.GetListSize(request, metadata=self.__metadata)

    @catch_grpc_error
    def resize_list_object(self, request):
        return self.__stub.ResizeListObject(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_obj_static_info(self, request):
        return self.__stub.GetObjectStaticInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_static_info(self, request):
        return self.__stub.GetStaticInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def execute_cmd(self, request):
        return self.__stub.ExecuteCommand(request, metadata=self.__metadata)

    @catch_grpc_error
    def execute_query(self, request):
        return self.__stub.ExecuteQuery(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_attrs(self, request):
        return self.__stub.GetAttrs(request, metadata=self.__metadata)


trace = False
_indent = 0


def _trace(fn):
    def _fn(self, *args, **kwds):
        global _indent
        if trace:
            print(f"{' '*_indent}fn={fn.__name__}, args={args} {{")
            try:
                _indent += 1
                ret = fn(self, *args, **kwds)
            finally:
                _indent -= 1
            print(f"{' '*_indent}fn = {fn.__name__}, ret={ret} }}")
            return ret
        else:
            return fn(self, *args, **kwds)

    return _fn


def _get_request_instance_for_path(request_class, path):
    request = request_class()
    request.path_info.path = path
    request.path_info.root = "fluent"
    return request


class SettingsService:
    """Service for accessing and modifying Fluent settings."""

    def __init__(self, channel, metadata):
        self.__service_impl = _SettingsServiceImpl(channel, metadata)

    @_trace
    def _set_state_from_value(self, state, value):
        if isinstance(value, bool):
            state.boolean = value
        elif isinstance(value, int):
            state.integer = value
        elif isinstance(value, float):
            state.real = value
        elif isinstance(value, str):
            state.string = value
        elif isinstance(value, collections.abc.Mapping):
            for k, v in value.items():
                self._set_state_from_value(state.value_map.m[k], v)
        elif isinstance(value, collections.abc.Iterable):
            for v in value:
                self._set_state_from_value(state.value_list.lst.add(), v)
        else:  # fall back to string (e.g. pathlib.Path)
            state.string = str(value)

    @_trace
    def _get_state_from_value(self, state):
        t = state.WhichOneof("value")
        if t == "boolean":
            return state.boolean
        elif t == "integer":
            return state.integer
        elif t == "real":
            return state.real
        elif t == "string":
            return state.string
        elif t == "value_list":
            return [self._get_state_from_value(v) for v in state.value_list.lst]
        elif t == "value_map":
            return {
                k: self._get_state_from_value(v) for k, v in state.value_map.m.items()
            }
        else:
            return None

    @_trace
    def set_var(self, path: str, value: Any):
        """Set the value for the given path."""
        request = _get_request_instance_for_path(SettingsModule.SetVarRequest, path)
        self._set_state_from_value(request.value, value)
        self.__service_impl.set_var(request)

    @_trace
    def get_var(self, path: str) -> Any:
        """Get the value for the given path."""
        request = _get_request_instance_for_path(SettingsModule.GetVarRequest, path)
        response = self.__service_impl.get_var(request)
        return self._get_state_from_value(response.value)

    @_trace
    def rename(self, path: str, new: str, old: str):
        """Rename the object at the given path."""
        request = _get_request_instance_for_path(SettingsModule.RenameRequest, path)
        request.old_name = old
        request.new_name = new

        self.__service_impl.rename(request)

    @_trace
    def create(self, path: str, name: str):
        """Create a named object child for the given path."""
        request = _get_request_instance_for_path(SettingsModule.CreateRequest, path)
        request.name = name

        self.__service_impl.create(request)

    @_trace
    def delete(self, path: str, name: str):
        """Delete the object with the given name at the given path."""
        request = _get_request_instance_for_path(SettingsModule.DeleteRequest, path)
        request.name = name

        self.__service_impl.delete(request)

    @_trace
    def get_object_names(self, path: str) -> List[int]:
        """Get a list of named objects."""
        request = _get_request_instance_for_path(
            SettingsModule.GetObjectNamesRequest, path
        )
        return self.__service_impl.get_object_names(request).names

    @_trace
    def get_list_size(self, path: str) -> int:
        """Get the number of elements in a list object."""
        request = _get_request_instance_for_path(
            SettingsModule.GetListSizeRequest, path
        )
        return self.__service_impl.get_list_size(request).size

    @_trace
    def resize_list_object(self, path: str, size: int):
        """Resize a list object."""
        request = _get_request_instance_for_path(
            SettingsModule.ResizeListObjectRequest, path
        )
        request.size = size
        return self.__service_impl.resize_list_object(request)

    @_trace
    def _extract_static_info(self, info):
        ret = {}
        ret["type"] = info.type
        if info.has_allowed_values:
            ret["has_allowed_values"] = info.has_allowed_values
        if info.children:
            ret["children"] = {
                child.name: self._extract_static_info(child.value)
                for child in info.children
            }
        if info.commands:
            ret["commands"] = {
                child.name: self._extract_static_info(child.value)
                for child in info.commands
            }
        if hasattr(info, "queries") and info.queries:
            ret["queries"] = {
                child.name: self._extract_static_info(child.value)
                for child in info.queries
            }
        if info.arguments:
            ret["arguments"] = {
                child.name: self._extract_static_info(child.value)
                for child in info.arguments
            }
        if info.HasField("object_type"):
            ret["object-type"] = self._extract_static_info(info.object_type)
        if info.help:
            ret["help"] = info.help

        try:
            if info.include_child_named_objects:
                ret["include_child_named_objects"] = info.include_child_named_objects
        except AttributeError:
            pass

        try:
            if info.list_size:
                ret["list_size"] = info.list_size
        except AttributeError:
            pass

        try:
            if info.user_creatable:
                ret["user_creatable"] = info.user_creatable
        except AttributeError:
            ret["user_creatable"] = True

        return ret

    @_trace
    def get_static_info(self):
        request = SettingsModule.GetStaticInfoRequest()
        request.root = "fluent"
        response = self.__service_impl.get_static_info(request)
        # The rpc calls no longer raise an exception. Force an exception if
        # type is empty
        if not response.info.type:
            raise RuntimeError
        return self._extract_static_info(response.info)

    @_trace
    def execute_cmd(self, path: str, command: str, **kwds) -> Any:
        """Execute a given command with the provided keyword arguments."""
        request = _get_request_instance_for_path(
            SettingsModule.ExecuteCommandRequest, path
        )
        request.command = command
        self._set_state_from_value(request.args, kwds)

        response = self.__service_impl.execute_cmd(request)
        return self._get_state_from_value(response.reply)

    @_trace
    def execute_query(self, path: str, query: str, **kwds) -> Any:
        """Execute a given query with the provided keyword arguments."""
        request = _get_request_instance_for_path(
            SettingsModule.ExecuteQueryRequest, path
        )
        request.query = query
        self._set_state_from_value(request.args, kwds)

        response = self.__service_impl.execute_query(request)
        return self._get_state_from_value(response.reply)

    @_trace
    def _parse_attrs(self, response):
        ret = {}
        ret["attrs"] = self._get_state_from_value(response.values)
        if response.group_children:
            ret["group_children"] = {
                child.name: self._parse_attrs(child.value)
                for child in response.group_children
            }
        if response.named_object_children:
            ret["named_object_children"] = {
                child.name: self._parse_attrs(child.value)
                for child in response.named_object_children
            }
        if response.list_object_children:
            ret["list_object_children"] = [
                self._parse_attrs(child) for child in response.list_object_children
            ]
        if response.arguments:
            ret["arguments"] = {
                child.name: self._parse_attrs(child.value)
                for child in response.arguments
            }
        return ret

    @_trace
    def get_attrs(self, path: str, attrs: List[str], recursive=False) -> Any:
        """Return values of given attributes."""
        request = _get_request_instance_for_path(SettingsModule.GetAttrsRequest, path)
        request.attrs[:] = attrs
        request.recursive = recursive

        response = self.__service_impl.get_attrs(request)
        if recursive:
            return self._parse_attrs(response)
        return self._get_state_from_value(response.values)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .buoyancy_force_linearization import buoyancy_force_linearization
from .blended_treatment_for_buoyancy_forces import blended_treatment_for_buoyancy_forces
class coupled_vof(Group):
    """
    'coupled_vof' child.
    """

    fluent_name = "coupled-vof"

    child_names = \
        ['buoyancy_force_linearization',
         'blended_treatment_for_buoyancy_forces']

    buoyancy_force_linearization: buoyancy_force_linearization = buoyancy_force_linearization
    """
    buoyancy_force_linearization child of coupled_vof.
    """
    blended_treatment_for_buoyancy_forces: blended_treatment_for_buoyancy_forces = blended_treatment_for_buoyancy_forces
    """
    blended_treatment_for_buoyancy_forces child of coupled_vof.
    """



"""Functions to download sample datasets from the PyAnsys data repository.

Examples
--------

>>> from ansys.fluent.core import examples
>>> filename = examples.download_file("bracket.iges", "geometry")
>>> filename
'/home/user/.local/share/ansys_fluent_core/examples/bracket.iges'
"""
import os
import shutil
from typing import Optional
import urllib.request
import zipfile

import ansys.fluent.core as pyfluent


def get_ext(filename: str) -> str:
    """Extract the extension of a file."""
    ext = os.path.splitext(filename)[1].lower()
    return ext


def delete_downloads() -> bool:
    """Delete all downloaded examples to free space or update the files."""
    shutil.rmtree(pyfluent.EXAMPLES_PATH)
    os.makedirs(pyfluent.EXAMPLES_PATH)
    return True


def _decompress(filename: str) -> None:
    zip_ref = zipfile.ZipFile(filename, "r")
    zip_ref.extractall(pyfluent.EXAMPLES_PATH)
    return zip_ref.close()


def _get_file_url(filename: str, directory: Optional[str] = None) -> str:
    if directory:
        return (
            "https://github.com/pyansys/example-data/raw/master/"
            f"{directory}/{filename}"
        )
    return f"https://github.com/pyansys/example-data/raw/master/{filename}"


def _retrieve_file(url: str, filename: str):
    # First check if file has already been downloaded
    local_path = os.path.join(pyfluent.EXAMPLES_PATH, os.path.basename(filename))
    local_path_no_zip = local_path.replace(".zip", "")
    if os.path.isfile(local_path_no_zip) or os.path.isdir(local_path_no_zip):
        return local_path_no_zip, None

    # grab the correct url retriever
    urlretrieve = urllib.request.urlretrieve

    # Perform download
    saved_file, resp = urlretrieve(url)
    shutil.move(saved_file, local_path)
    if get_ext(local_path) in [".zip"]:
        _decompress(local_path)
        local_path = local_path[:-4]
    return local_path, resp


def download_file(filename: str, directory: Optional[str] = None):
    url = _get_file_url(filename, directory)
    return _retrieve_file(url, filename)[0]



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_high_res_tracking import enable_high_res_tracking
from .expert_options_1 import expert_options
from .high_res_tracking_options import high_res_tracking_options
from .tracking_parameters import tracking_parameters
from .track_in_absolute_frame import track_in_absolute_frame
class tracking(Group):
    """
    Main menu to control the time integration of the particle trajectory equations.
    """

    fluent_name = "tracking"

    child_names = \
        ['enable_high_res_tracking', 'expert_options',
         'high_res_tracking_options', 'tracking_parameters',
         'track_in_absolute_frame']

    enable_high_res_tracking: enable_high_res_tracking = enable_high_res_tracking
    """
    enable_high_res_tracking child of tracking.
    """
    expert_options: expert_options = expert_options
    """
    expert_options child of tracking.
    """
    high_res_tracking_options: high_res_tracking_options = high_res_tracking_options
    """
    high_res_tracking_options child of tracking.
    """
    tracking_parameters: tracking_parameters = tracking_parameters
    """
    tracking_parameters child of tracking.
    """
    track_in_absolute_frame: track_in_absolute_frame = track_in_absolute_frame
    """
    track_in_absolute_frame child of tracking.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .injection_names import injection_names
class particle_summary(Command):
    """
    Print summary report for all current particles.
    
    Parameters
    ----------
        injection_names : typing.List[str]
            'injection_names' child.
    
    """

    fluent_name = "particle-summary"

    argument_names = \
        ['injection_names']

    injection_names: injection_names = injection_names
    """
    injection_names argument of particle_summary.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .moving_mesh_constraint import moving_mesh_constraint
from .mesh_courant_number import mesh_courant_number
class moving_mesh_cfl_constraint(Group):
    """
    'moving_mesh_cfl_constraint' child.
    """

    fluent_name = "moving-mesh-cfl-constraint"

    child_names = \
        ['moving_mesh_constraint', 'mesh_courant_number']

    moving_mesh_constraint: moving_mesh_constraint = moving_mesh_constraint
    """
    moving_mesh_constraint child of moving_mesh_cfl_constraint.
    """
    mesh_courant_number: mesh_courant_number = mesh_courant_number
    """
    mesh_courant_number child of moving_mesh_cfl_constraint.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .coefficient import coefficient
from .dissipation import dissipation
from .viscous_1 import viscous
class multi_stage_child(Group):
    """
    'child_object_type' of multi_stage.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['coefficient', 'dissipation', 'viscous']

    coefficient: coefficient = coefficient
    """
    coefficient child of multi_stage_child.
    """
    dissipation: dissipation = dissipation
    """
    dissipation child of multi_stage_child.
    """
    viscous: viscous = viscous
    """
    viscous child of multi_stage_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option import option
from .constant import constant
from .profile_name import profile_name
from .field_name import field_name
from .udf import udf
class film_u_src(Group):
    """
    'film_u_src' child.
    """

    fluent_name = "film-u-src"

    child_names = \
        ['option', 'constant', 'profile_name', 'field_name', 'udf']

    option: option = option
    """
    option child of film_u_src.
    """
    constant: constant = constant
    """
    constant child of film_u_src.
    """
    profile_name: profile_name = profile_name
    """
    profile_name child of film_u_src.
    """
    field_name: field_name = field_name
    """
    field_name child of film_u_src.
    """
    udf: udf = udf
    """
    udf child of film_u_src.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .consistency_index import consistency_index
from .power_law_index import power_law_index
from .minimum_viscosity import minimum_viscosity
from .maximum_viscosity import maximum_viscosity
from .reference_temperature import reference_temperature
from .activation_energy import activation_energy
class non_newtonian_power_law(Group):
    """
    'non_newtonian_power_law' child.
    """

    fluent_name = "non-newtonian-power-law"

    child_names = \
        ['option', 'consistency_index', 'power_law_index',
         'minimum_viscosity', 'maximum_viscosity', 'reference_temperature',
         'activation_energy']

    option: option = option
    """
    option child of non_newtonian_power_law.
    """
    consistency_index: consistency_index = consistency_index
    """
    consistency_index child of non_newtonian_power_law.
    """
    power_law_index: power_law_index = power_law_index
    """
    power_law_index child of non_newtonian_power_law.
    """
    minimum_viscosity: minimum_viscosity = minimum_viscosity
    """
    minimum_viscosity child of non_newtonian_power_law.
    """
    maximum_viscosity: maximum_viscosity = maximum_viscosity
    """
    maximum_viscosity child of non_newtonian_power_law.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of non_newtonian_power_law.
    """
    activation_energy: activation_energy = activation_energy
    """
    activation_energy child of non_newtonian_power_law.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .density_3 import density
from .thermal_conductivity_3 import thermal_conductivity
from .vaporization_model import vaporization_model
from .thermolysis_model import thermolysis_model
from .latent_heat_1 import latent_heat
from .volatile_fraction import volatile_fraction
from .heat_of_pyrolysis import heat_of_pyrolysis
from .specific_heat_3 import specific_heat
from .binary_diffusivity_1 import binary_diffusivity
from .diffusivity_reference_pressure import diffusivity_reference_pressure
from .averaging_coefficient_t import averaging_coefficient_t
from .averaging_coefficient_y import averaging_coefficient_y
from .vapor_pressure import vapor_pressure
from .molecular_weight_1 import molecular_weight
from .vaporization_temperature import vaporization_temperature
from .boiling_point import boiling_point
from .thermophoretic_co import thermophoretic_co
from .scattering_factor_1 import scattering_factor
from .emissivity_1 import emissivity
from .viscosity_2 import viscosity
from .dpm_surften_1 import dpm_surften
from .electric_conductivity_1 import electric_conductivity
from .dual_electric_conductivity_1 import dual_electric_conductivity
from .magnetic_permeability import magnetic_permeability
from .charge_density import charge_density
class droplet_particle_child(Group):
    """
    'child_object_type' of droplet_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'thermal_conductivity', 'vaporization_model',
         'thermolysis_model', 'latent_heat', 'volatile_fraction',
         'heat_of_pyrolysis', 'specific_heat', 'binary_diffusivity',
         'diffusivity_reference_pressure', 'averaging_coefficient_t',
         'averaging_coefficient_y', 'vapor_pressure', 'molecular_weight',
         'vaporization_temperature', 'boiling_point', 'thermophoretic_co',
         'scattering_factor', 'emissivity', 'viscosity', 'dpm_surften',
         'electric_conductivity', 'dual_electric_conductivity',
         'magnetic_permeability', 'charge_density']

    density: density = density
    """
    density child of droplet_particle_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of droplet_particle_child.
    """
    vaporization_model: vaporization_model = vaporization_model
    """
    vaporization_model child of droplet_particle_child.
    """
    thermolysis_model: thermolysis_model = thermolysis_model
    """
    thermolysis_model child of droplet_particle_child.
    """
    latent_heat: latent_heat = latent_heat
    """
    latent_heat child of droplet_particle_child.
    """
    volatile_fraction: volatile_fraction = volatile_fraction
    """
    volatile_fraction child of droplet_particle_child.
    """
    heat_of_pyrolysis: heat_of_pyrolysis = heat_of_pyrolysis
    """
    heat_of_pyrolysis child of droplet_particle_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of droplet_particle_child.
    """
    binary_diffusivity: binary_diffusivity = binary_diffusivity
    """
    binary_diffusivity child of droplet_particle_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure = diffusivity_reference_pressure
    """
    diffusivity_reference_pressure child of droplet_particle_child.
    """
    averaging_coefficient_t: averaging_coefficient_t = averaging_coefficient_t
    """
    averaging_coefficient_t child of droplet_particle_child.
    """
    averaging_coefficient_y: averaging_coefficient_y = averaging_coefficient_y
    """
    averaging_coefficient_y child of droplet_particle_child.
    """
    vapor_pressure: vapor_pressure = vapor_pressure
    """
    vapor_pressure child of droplet_particle_child.
    """
    molecular_weight: molecular_weight = molecular_weight
    """
    molecular_weight child of droplet_particle_child.
    """
    vaporization_temperature: vaporization_temperature = vaporization_temperature
    """
    vaporization_temperature child of droplet_particle_child.
    """
    boiling_point: boiling_point = boiling_point
    """
    boiling_point child of droplet_particle_child.
    """
    thermophoretic_co: thermophoretic_co = thermophoretic_co
    """
    thermophoretic_co child of droplet_particle_child.
    """
    scattering_factor: scattering_factor = scattering_factor
    """
    scattering_factor child of droplet_particle_child.
    """
    emissivity: emissivity = emissivity
    """
    emissivity child of droplet_particle_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of droplet_particle_child.
    """
    dpm_surften: dpm_surften = dpm_surften
    """
    dpm_surften child of droplet_particle_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of droplet_particle_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of droplet_particle_child.
    """
    magnetic_permeability: magnetic_permeability = magnetic_permeability
    """
    magnetic_permeability child of droplet_particle_child.
    """
    charge_density: charge_density = charge_density
    """
    charge_density child of droplet_particle_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fmg_courant_number import fmg_courant_number
from .enable_fmg_verbose import enable_fmg_verbose
from .customize_fmg_initialization import customize_fmg_initialization
class fmg_initialization(Group):
    """
    Enter the set full-multigrid for initialization menu.
    """

    fluent_name = "fmg-initialization"

    child_names = \
        ['fmg_courant_number', 'enable_fmg_verbose']

    fmg_courant_number: fmg_courant_number = fmg_courant_number
    """
    fmg_courant_number child of fmg_initialization.
    """
    enable_fmg_verbose: enable_fmg_verbose = enable_fmg_verbose
    """
    enable_fmg_verbose child of fmg_initialization.
    """
    command_names = \
        ['customize_fmg_initialization']

    customize_fmg_initialization: customize_fmg_initialization = customize_fmg_initialization
    """
    customize_fmg_initialization command of fmg_initialization.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .print_level import print_level
class mesh_info(Command):
    """
    'mesh_info' command.
    
    Parameters
    ----------
        print_level : int
            Print zone information size.
    
    """

    fluent_name = "mesh-info"

    argument_names = \
        ['print_level']

    print_level: print_level = print_level
    """
    print_level argument of mesh_info.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .residual_smoothing_factor import residual_smoothing_factor
from .residual_smoothing_iter_count import residual_smoothing_iter_count
class residual_smoothing(Group):
    """
    Set residual smoothing factor and number of iterations.
    """

    fluent_name = "residual-smoothing"

    child_names = \
        ['residual_smoothing_factor', 'residual_smoothing_iter_count']

    residual_smoothing_factor: residual_smoothing_factor = residual_smoothing_factor
    """
    residual_smoothing_factor child of residual_smoothing.
    """
    residual_smoothing_iter_count: residual_smoothing_iter_count = residual_smoothing_iter_count
    """
    residual_smoothing_iter_count child of residual_smoothing.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .flux_type import flux_type
class dbns_cases(Group):
    """
    'dbns_cases' child.
    """

    fluent_name = "dbns_cases"

    child_names = \
        ['flux_type']

    flux_type: flux_type = flux_type
    """
    flux_type child of dbns_cases.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .method import method
from .samp_time_period import samp_time_period
from .samp_time_steps import samp_time_steps
from .avg_time_period import avg_time_period
from .avg_time_steps import avg_time_steps
class statistics_controls(Command):
    """
    'statistics_controls' command.
    
    Parameters
    ----------
        method : int
            'method' child.
        samp_time_period : real
            'samp_time_period' child.
        samp_time_steps : int
            'samp_time_steps' child.
        avg_time_period : real
            'avg_time_period' child.
        avg_time_steps : int
            'avg_time_steps' child.
    
    """

    fluent_name = "statistics-controls"

    argument_names = \
        ['method', 'samp_time_period', 'samp_time_steps', 'avg_time_period',
         'avg_time_steps']

    method: method = method
    """
    method argument of statistics_controls.
    """
    samp_time_period: samp_time_period = samp_time_period
    """
    samp_time_period argument of statistics_controls.
    """
    samp_time_steps: samp_time_steps = samp_time_steps
    """
    samp_time_steps argument of statistics_controls.
    """
    avg_time_period: avg_time_period = avg_time_period
    """
    avg_time_period argument of statistics_controls.
    """
    avg_time_steps: avg_time_steps = avg_time_steps
    """
    avg_time_steps argument of statistics_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .diffusion_rate_constant import diffusion_rate_constant
from .pre_exponential_factor import pre_exponential_factor
from .activation_energy import activation_energy
from .char_porosity import char_porosity
from .mean_pore_radius import mean_pore_radius
from .specific_internal_surface_area import specific_internal_surface_area
from .tortuosity import tortuosity
from .burning_mode import burning_mode
class intrinsic_model(Group):
    """
    'intrinsic_model' child.
    """

    fluent_name = "intrinsic-model"

    child_names = \
        ['diffusion_rate_constant', 'pre_exponential_factor',
         'activation_energy', 'char_porosity', 'mean_pore_radius',
         'specific_internal_surface_area', 'tortuosity', 'burning_mode']

    diffusion_rate_constant: diffusion_rate_constant = diffusion_rate_constant
    """
    diffusion_rate_constant child of intrinsic_model.
    """
    pre_exponential_factor: pre_exponential_factor = pre_exponential_factor
    """
    pre_exponential_factor child of intrinsic_model.
    """
    activation_energy: activation_energy = activation_energy
    """
    activation_energy child of intrinsic_model.
    """
    char_porosity: char_porosity = char_porosity
    """
    char_porosity child of intrinsic_model.
    """
    mean_pore_radius: mean_pore_radius = mean_pore_radius
    """
    mean_pore_radius child of intrinsic_model.
    """
    specific_internal_surface_area: specific_internal_surface_area = specific_internal_surface_area
    """
    specific_internal_surface_area child of intrinsic_model.
    """
    tortuosity: tortuosity = tortuosity
    """
    tortuosity child of intrinsic_model.
    """
    burning_mode: burning_mode = burning_mode
    """
    burning_mode child of intrinsic_model.
    """



"""Interceptor classes to use with gRPC services."""

from typing import Any

from google.protobuf.json_format import MessageToDict
import grpc

from ansys.fluent.core.utils.logging import LOG


class TracingInterceptor(grpc.UnaryUnaryClientInterceptor):
    """Interceptor class to trace gRPC calls."""

    def _intercept_call(
        self,
        continuation: Any,
        client_call_details: grpc.ClientCallDetails,
        request: Any,
    ):
        LOG.debug(
            "GRPC_TRACE: rpc = %s, request = %s",
            client_call_details.method,
            MessageToDict(request),
        )
        response = continuation(client_call_details, request)
        if not response.exception():
            LOG.debug(
                "GRPC_TRACE: response = %s",
                MessageToDict(response.result()),
            )
        return response

    def intercept_unary_unary(
        self,
        continuation: Any,
        client_call_details: grpc.ClientCallDetails,
        request: Any,
    ) -> Any:
        return self._intercept_call(continuation, client_call_details, request)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .file import file
from .mesh import mesh
from .server import server
from .setup import setup
from .solution import solution
from .results import results
from .parametric_studies import parametric_studies
from .current_parametric_study import current_parametric_study
from .parallel_1 import parallel
from .report_1 import report
from .exit import exit
class root(Group):
    """
    'root' object.
    """

    fluent_name = ""

    child_names = \
        ['file', 'mesh', 'server', 'setup', 'solution', 'results',
         'parametric_studies', 'current_parametric_study', 'parallel',
         'report']

    file: file = file
    """
    file child of root.
    """
    mesh: mesh = mesh
    """
    mesh child of root.
    """
    server: server = server
    """
    server child of root.
    """
    setup: setup = setup
    """
    setup child of root.
    """
    solution: solution = solution
    """
    solution child of root.
    """
    results: results = results
    """
    results child of root.
    """
    parametric_studies: parametric_studies = parametric_studies
    """
    parametric_studies child of root.
    """
    current_parametric_study: current_parametric_study = current_parametric_study
    """
    current_parametric_study child of root.
    """
    parallel: parallel = parallel
    """
    parallel child of root.
    """
    report: report = report
    """
    report child of root.
    """
    command_names = \
        ['exit']

    exit: exit = exit
    """
    exit command of root.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .solve_flow_last import solve_flow_last
from .solve_exp_vof_at_end import solve_exp_vof_at_end
class equation_order(Group):
    """
    'equation_order' child.
    """

    fluent_name = "equation-order"

    child_names = \
        ['solve_flow_last', 'solve_exp_vof_at_end']

    solve_flow_last: solve_flow_last = solve_flow_last
    """
    solve_flow_last child of equation_order.
    """
    solve_exp_vof_at_end: solve_exp_vof_at_end = solve_exp_vof_at_end
    """
    solve_exp_vof_at_end child of equation_order.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .symbol import symbol
from .size_1 import size
from .color import color
class markers_child(Group):
    """
    'child_object_type' of markers.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['symbol', 'size', 'color']

    symbol: symbol = symbol
    """
    symbol child of markers_child.
    """
    size: size = size
    """
    size child of markers_child.
    """
    color: color = color
    """
    color child of markers_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x_axis_2 import x_axis
from .y_axis_2 import y_axis
class log_scale(Group):
    """
    'log_scale' child.
    """

    fluent_name = "log-scale"

    child_names = \
        ['x_axis', 'y_axis']

    x_axis: x_axis = x_axis
    """
    x_axis child of log_scale.
    """
    y_axis: y_axis = y_axis
    """
    y_axis child of log_scale.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class trim_option(Integer):
    """
    Select Trimming Option:
    
     - Enter 0 if no trimming is required 
     - Enter 1 if trimming of collective pitch is required 
     - Enter 2 if trimming of cyclic pitch angles are required 
     - Enter 3 if trimming of both collective and cyclic pitch angles are required 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "trim-option"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .compute import compute
class compute(Group):
    """
    'compute' child.
    """

    fluent_name = "compute"

    child_names = \
        ['compute']

    compute: compute = compute
    """
    compute child of compute.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .general_1 import general
from .geometry_1 import geometry
from .trimming import trimming
class disk_child(Group):
    """
    'child_object_type' of disk.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['general', 'geometry', 'trimming']

    general: general = general
    """
    general child of disk_child.
    """
    geometry: geometry = geometry
    """
    geometry child of disk_child.
    """
    trimming: trimming = trimming
    """
    trimming child of disk_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .set_custom_frames import set_custom_frames
from .video_1 import video
from .read_animation import read_animation
from .write_animation import write_animation
from .stored_view import stored_view
class playback(Group):
    """
    'playback' child.
    """

    fluent_name = "playback"

    child_names = \
        ['set_custom_frames', 'video']

    set_custom_frames: set_custom_frames = set_custom_frames
    """
    set_custom_frames child of playback.
    """
    video: video = video
    """
    video child of playback.
    """
    command_names = \
        ['read_animation', 'write_animation', 'stored_view']

    read_animation: read_animation = read_animation
    """
    read_animation command of playback.
    """
    write_animation: write_animation = write_animation
    """
    write_animation command of playback.
    """
    stored_view: stored_view = stored_view
    """
    stored_view command of playback.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .dolly import dolly
from .field_1 import field
from .orbit import orbit
from .pan import pan
from .position_1 import position
from .projection import projection
from .roll import roll
from .target import target
from .up_vector import up_vector
from .zoom import zoom
class camera(Group):
    """
    'camera' child.
    """

    fluent_name = "camera"

    command_names = \
        ['dolly', 'field', 'orbit', 'pan', 'position', 'projection', 'roll',
         'target', 'up_vector', 'zoom']

    dolly: dolly = dolly
    """
    dolly command of camera.
    """
    field: field = field
    """
    field command of camera.
    """
    orbit: orbit = orbit
    """
    orbit command of camera.
    """
    pan: pan = pan
    """
    pan command of camera.
    """
    position: position = position
    """
    position command of camera.
    """
    projection: projection = projection
    """
    projection command of camera.
    """
    roll: roll = roll
    """
    roll command of camera.
    """
    target: target = target
    """
    target command of camera.
    """
    up_vector: up_vector = up_vector
    """
    up_vector command of camera.
    """
    zoom: zoom = zoom
    """
    zoom command of camera.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class unstable_event_outer_iterations(Integer):
    """
    Set number of outer iterations for unstable event.
    """

    fluent_name = "unstable-event-outer-iterations"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class iterations(Integer):
    """
    Set the frequency (in iterations) at which cells in the register are automatically marked for poor mesh numerics treatment.
    """

    fluent_name = "iterations"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .blended_compressive_scheme import blended_compressive_scheme
from .pseudo_transient_stabilization import pseudo_transient_stabilization
class additional_stabilization_controls(Group):
    """
    'additional_stabilization_controls' child.
    """

    fluent_name = "additional-stabilization-controls"

    child_names = \
        ['blended_compressive_scheme', 'pseudo_transient_stabilization']

    blended_compressive_scheme: blended_compressive_scheme = blended_compressive_scheme
    """
    blended_compressive_scheme child of additional_stabilization_controls.
    """
    pseudo_transient_stabilization: pseudo_transient_stabilization = pseudo_transient_stabilization
    """
    pseudo_transient_stabilization child of additional_stabilization_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .heat_flux_relaxation_factor import heat_flux_relaxation_factor
from .show_expert_options import show_expert_options
from .two_resistance_boiling_framework import two_resistance_boiling_framework
class boiling(Group):
    """
    'boiling' child.
    """

    fluent_name = "boiling"

    child_names = \
        ['heat_flux_relaxation_factor', 'show_expert_options',
         'two_resistance_boiling_framework']

    heat_flux_relaxation_factor: heat_flux_relaxation_factor = heat_flux_relaxation_factor
    """
    heat_flux_relaxation_factor child of boiling.
    """
    show_expert_options: show_expert_options = show_expert_options
    """
    show_expert_options child of boiling.
    """
    two_resistance_boiling_framework: two_resistance_boiling_framework = two_resistance_boiling_framework
    """
    two_resistance_boiling_framework child of boiling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .start import start
from .stop import stop
class web_server(Group):
    """
    'web_server' child.
    """

    fluent_name = "web-server"

    command_names = \
        ['start', 'stop']

    start: start = start
    """
    start command of web_server.
    """
    stop: stop = stop
    """
    stop command of web_server.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .constant_y0 import constant_y0
from .number_of_child_droplets import number_of_child_droplets
from .constant_b1 import constant_b1
from .constant_b0 import constant_b0
from .constant_cl import constant_cl
from .constant_ctau import constant_ctau
from .constant_crt import constant_crt
from .critical_weber_number import critical_weber_number
from .core_b1 import core_b1
from .constant_xi import constant_xi
from .target_number_in_parcel import target_number_in_parcel
from .constant_c0 import constant_c0
from .column_drag_coeff import column_drag_coeff
from .ligament_factor import ligament_factor
from .jet_diameter import jet_diameter
from .constant_k1 import constant_k1
from .constant_k2 import constant_k2
from .constant_tb import constant_tb
class droplet_breakup(Group):
    """
    'droplet_breakup' child.
    """

    fluent_name = "droplet-breakup"

    child_names = \
        ['option', 'constant_y0', 'number_of_child_droplets', 'constant_b1',
         'constant_b0', 'constant_cl', 'constant_ctau', 'constant_crt',
         'critical_weber_number', 'core_b1', 'constant_xi',
         'target_number_in_parcel', 'constant_c0', 'column_drag_coeff',
         'ligament_factor', 'jet_diameter', 'constant_k1', 'constant_k2',
         'constant_tb']

    option: option = option
    """
    option child of droplet_breakup.
    """
    constant_y0: constant_y0 = constant_y0
    """
    constant_y0 child of droplet_breakup.
    """
    number_of_child_droplets: number_of_child_droplets = number_of_child_droplets
    """
    number_of_child_droplets child of droplet_breakup.
    """
    constant_b1: constant_b1 = constant_b1
    """
    constant_b1 child of droplet_breakup.
    """
    constant_b0: constant_b0 = constant_b0
    """
    constant_b0 child of droplet_breakup.
    """
    constant_cl: constant_cl = constant_cl
    """
    constant_cl child of droplet_breakup.
    """
    constant_ctau: constant_ctau = constant_ctau
    """
    constant_ctau child of droplet_breakup.
    """
    constant_crt: constant_crt = constant_crt
    """
    constant_crt child of droplet_breakup.
    """
    critical_weber_number: critical_weber_number = critical_weber_number
    """
    critical_weber_number child of droplet_breakup.
    """
    core_b1: core_b1 = core_b1
    """
    core_b1 child of droplet_breakup.
    """
    constant_xi: constant_xi = constant_xi
    """
    constant_xi child of droplet_breakup.
    """
    target_number_in_parcel: target_number_in_parcel = target_number_in_parcel
    """
    target_number_in_parcel child of droplet_breakup.
    """
    constant_c0: constant_c0 = constant_c0
    """
    constant_c0 child of droplet_breakup.
    """
    column_drag_coeff: column_drag_coeff = column_drag_coeff
    """
    column_drag_coeff child of droplet_breakup.
    """
    ligament_factor: ligament_factor = ligament_factor
    """
    ligament_factor child of droplet_breakup.
    """
    jet_diameter: jet_diameter = jet_diameter
    """
    jet_diameter child of droplet_breakup.
    """
    constant_k1: constant_k1 = constant_k1
    """
    constant_k1 child of droplet_breakup.
    """
    constant_k2: constant_k2 = constant_k2
    """
    constant_k2 child of droplet_breakup.
    """
    constant_tb: constant_tb = constant_tb
    """
    constant_tb child of droplet_breakup.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .refinement_criteria import refinement_criteria
from .coarsening_criteria import coarsening_criteria
from .manual_refinement_criteria import manual_refinement_criteria
from .manual_coarsening_criteria import manual_coarsening_criteria
from .set import set
from .profile import profile
from .free_hierarchy import free_hierarchy
from .multi_layer_refinement import multi_layer_refinement
from .geometry import geometry
from .adapt_mesh import adapt_mesh
from .display_adaption_cells import display_adaption_cells
from .list_adaption_cells import list_adaption_cells
class adapt(Group):
    """
    'adapt' child.
    """

    fluent_name = "adapt"

    child_names = \
        ['refinement_criteria', 'coarsening_criteria',
         'manual_refinement_criteria', 'manual_coarsening_criteria', 'set',
         'profile', 'free_hierarchy', 'multi_layer_refinement', 'geometry']

    refinement_criteria: refinement_criteria = refinement_criteria
    """
    refinement_criteria child of adapt.
    """
    coarsening_criteria: coarsening_criteria = coarsening_criteria
    """
    coarsening_criteria child of adapt.
    """
    manual_refinement_criteria: manual_refinement_criteria = manual_refinement_criteria
    """
    manual_refinement_criteria child of adapt.
    """
    manual_coarsening_criteria: manual_coarsening_criteria = manual_coarsening_criteria
    """
    manual_coarsening_criteria child of adapt.
    """
    set: set = set
    """
    set child of adapt.
    """
    profile: profile = profile
    """
    profile child of adapt.
    """
    free_hierarchy: free_hierarchy = free_hierarchy
    """
    free_hierarchy child of adapt.
    """
    multi_layer_refinement: multi_layer_refinement = multi_layer_refinement
    """
    multi_layer_refinement child of adapt.
    """
    geometry: geometry = geometry
    """
    geometry child of adapt.
    """
    command_names = \
        ['adapt_mesh', 'display_adaption_cells', 'list_adaption_cells']

    adapt_mesh: adapt_mesh = adapt_mesh
    """
    adapt_mesh command of adapt.
    """
    display_adaption_cells: display_adaption_cells = display_adaption_cells
    """
    display_adaption_cells command of adapt.
    """
    list_adaption_cells: list_adaption_cells = list_adaption_cells
    """
    list_adaption_cells command of adapt.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enhanced_cell_relocation_method import enhanced_cell_relocation_method
from .load_legacy_particles import load_legacy_particles
from .overset_relocation_robustness_level import overset_relocation_robustness_level
from .use_legacy_particle_location_method import use_legacy_particle_location_method
class particle_relocation(Group):
    """
    Main menu holding information options to control relocating particles during case file reading or remeshing/adaption.
    """

    fluent_name = "particle-relocation"

    child_names = \
        ['enhanced_cell_relocation_method', 'load_legacy_particles',
         'overset_relocation_robustness_level',
         'use_legacy_particle_location_method']

    enhanced_cell_relocation_method: enhanced_cell_relocation_method = enhanced_cell_relocation_method
    """
    enhanced_cell_relocation_method child of particle_relocation.
    """
    load_legacy_particles: load_legacy_particles = load_legacy_particles
    """
    load_legacy_particles child of particle_relocation.
    """
    overset_relocation_robustness_level: overset_relocation_robustness_level = overset_relocation_robustness_level
    """
    overset_relocation_robustness_level child of particle_relocation.
    """
    use_legacy_particle_location_method: use_legacy_particle_location_method = use_legacy_particle_location_method
    """
    use_legacy_particle_location_method child of particle_relocation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .coupled_vof import coupled_vof
from .rhie_chow_flux import rhie_chow_flux
from .skewness_correction import skewness_correction
class p_v_coupling(Group):
    """
    Pressure velocity coupling controls for multiphase flow.
    """

    fluent_name = "p-v-coupling"

    child_names = \
        ['coupled_vof', 'rhie_chow_flux', 'skewness_correction']

    coupled_vof: coupled_vof = coupled_vof
    """
    coupled_vof child of p_v_coupling.
    """
    rhie_chow_flux: rhie_chow_flux = rhie_chow_flux
    """
    rhie_chow_flux child of p_v_coupling.
    """
    skewness_correction: skewness_correction = skewness_correction
    """
    skewness_correction child of p_v_coupling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .display_1 import display
from .copy_3 import copy
from .add_to_graphics import add_to_graphics
from .clear_history import clear_history
from .contour_child import contour_child

class contour(NamedObject[contour_child], _CreatableNamedObjectMixin[contour_child]):
    """
    'contour' child.
    """

    fluent_name = "contour"

    command_names = \
        ['display', 'copy', 'add_to_graphics', 'clear_history']

    display: display = display
    """
    display command of contour.
    """
    copy: copy = copy
    """
    copy command of contour.
    """
    add_to_graphics: add_to_graphics = add_to_graphics
    """
    add_to_graphics command of contour.
    """
    clear_history: clear_history = clear_history
    """
    clear_history command of contour.
    """
    child_object_type: contour_child = contour_child
    """
    child_object_type of contour.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .species import species
from .reactions import reactions
from .reaction_mechs import reaction_mechs
from .density import density
from .specific_heat import specific_heat
from .thermal_conductivity import thermal_conductivity
from .viscosity import viscosity
from .molecular_weight import molecular_weight
from .mass_diffusivity import mass_diffusivity
from .thermal_diffusivity import thermal_diffusivity
from .formation_enthalpy import formation_enthalpy
from .formation_entropy import formation_entropy
from .characteristic_vibrational_temperature import characteristic_vibrational_temperature
from .reference_temperature import reference_temperature
from .lennard_jones_length import lennard_jones_length
from .lennard_jones_energy import lennard_jones_energy
from .thermal_accom_coefficient import thermal_accom_coefficient
from .velocity_accom_coefficient import velocity_accom_coefficient
from .absorption_coefficient import absorption_coefficient
from .scattering_coefficient import scattering_coefficient
from .scattering_phase_function import scattering_phase_function
from .therm_exp_coeff import therm_exp_coeff
from .premix_unburnt_density import premix_unburnt_density
from .premix_unburnt_temp import premix_unburnt_temp
from .premix_adiabatic_temp import premix_adiabatic_temp
from .premix_unburnt_cp import premix_unburnt_cp
from .premix_heat_trans_coeff import premix_heat_trans_coeff
from .premix_laminar_speed import premix_laminar_speed
from .premix_laminar_thickness import premix_laminar_thickness
from .premix_critical_strain import premix_critical_strain
from .premix_heat_of_comb import premix_heat_of_comb
from .premix_unburnt_fuel_mf import premix_unburnt_fuel_mf
from .refractive_index import refractive_index
from .latent_heat import latent_heat
from .thermophoretic_co import thermophoretic_co
from .vaporization_temperature import vaporization_temperature
from .boiling_point import boiling_point
from .volatile_fraction import volatile_fraction
from .binary_diffusivity import binary_diffusivity
from .diffusivity_reference_pressure import diffusivity_reference_pressure
from .vapor_pressure import vapor_pressure
from .degrees_of_freedom import degrees_of_freedom
from .emissivity import emissivity
from .scattering_factor import scattering_factor
from .heat_of_pyrolysis import heat_of_pyrolysis
from .swelling_coefficient import swelling_coefficient
from .burn_stoichiometry import burn_stoichiometry
from .combustible_fraction import combustible_fraction
from .burn_hreact import burn_hreact
from .burn_hreact_fraction import burn_hreact_fraction
from .devolatilization_model import devolatilization_model
from .combustion_model import combustion_model
from .averaging_coefficient_t import averaging_coefficient_t
from .averaging_coefficient_y import averaging_coefficient_y
from .vaporization_model import vaporization_model
from .thermolysis_model import thermolysis_model
from .melting_heat import melting_heat
from .tsolidus import tsolidus
from .tliqidus import tliqidus
from .tmelt import tmelt
from .liquidus_slope import liquidus_slope
from .partition_coeff import partition_coeff
from .eutectic_mf import eutectic_mf
from .eutectic_temp import eutectic_temp
from .solut_exp_coeff import solut_exp_coeff
from .solid_diffusion import solid_diffusion
from .uds_diffusivity import uds_diffusivity
from .dpm_surften import dpm_surften
from .electric_conductivity import electric_conductivity
from .dual_electric_conductivity import dual_electric_conductivity
from .lithium_diffusivity import lithium_diffusivity
from .magnetic_permeability import magnetic_permeability
from .charge_density import charge_density
from .charge import charge
from .speed_of_sound import speed_of_sound
from .species_phase import species_phase
from .vp_equilib import vp_equilib
from .critical_temperature import critical_temperature
from .critical_pressure import critical_pressure
from .critical_volume import critical_volume
from .acentric_factor import acentric_factor
from .saturation_pressure import saturation_pressure
from .struct_youngs_modulus import struct_youngs_modulus
from .struct_poisson_ratio import struct_poisson_ratio
from .struct_start_temperature import struct_start_temperature
from .struct_thermal_expansion import struct_thermal_expansion
from .atomic_number import atomic_number
from .struct_damping_alpha import struct_damping_alpha
from .struct_damping_beta import struct_damping_beta
from .mixture_species import mixture_species
class mixture_child(Group):
    """
    'child_object_type' of mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['species', 'reactions', 'reaction_mechs', 'density', 'specific_heat',
         'thermal_conductivity', 'viscosity', 'molecular_weight',
         'mass_diffusivity', 'thermal_diffusivity', 'formation_enthalpy',
         'formation_entropy', 'characteristic_vibrational_temperature',
         'reference_temperature', 'lennard_jones_length',
         'lennard_jones_energy', 'thermal_accom_coefficient',
         'velocity_accom_coefficient', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'therm_exp_coeff', 'premix_unburnt_density', 'premix_unburnt_temp',
         'premix_adiabatic_temp', 'premix_unburnt_cp',
         'premix_heat_trans_coeff', 'premix_laminar_speed',
         'premix_laminar_thickness', 'premix_critical_strain',
         'premix_heat_of_comb', 'premix_unburnt_fuel_mf', 'refractive_index',
         'latent_heat', 'thermophoretic_co', 'vaporization_temperature',
         'boiling_point', 'volatile_fraction', 'binary_diffusivity',
         'diffusivity_reference_pressure', 'vapor_pressure',
         'degrees_of_freedom', 'emissivity', 'scattering_factor',
         'heat_of_pyrolysis', 'swelling_coefficient', 'burn_stoichiometry',
         'combustible_fraction', 'burn_hreact', 'burn_hreact_fraction',
         'devolatilization_model', 'combustion_model',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'vaporization_model', 'thermolysis_model', 'melting_heat',
         'tsolidus', 'tliqidus', 'tmelt', 'liquidus_slope', 'partition_coeff',
         'eutectic_mf', 'eutectic_temp', 'solut_exp_coeff', 'solid_diffusion',
         'uds_diffusivity', 'dpm_surften', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'magnetic_permeability', 'charge_density', 'charge',
         'speed_of_sound', 'species_phase', 'vp_equilib',
         'critical_temperature', 'critical_pressure', 'critical_volume',
         'acentric_factor', 'saturation_pressure', 'struct_youngs_modulus',
         'struct_poisson_ratio', 'struct_start_temperature',
         'struct_thermal_expansion', 'atomic_number', 'struct_damping_alpha',
         'struct_damping_beta', 'mixture_species']

    species: species = species
    """
    species child of mixture_child.
    """
    reactions: reactions = reactions
    """
    reactions child of mixture_child.
    """
    reaction_mechs: reaction_mechs = reaction_mechs
    """
    reaction_mechs child of mixture_child.
    """
    density: density = density
    """
    density child of mixture_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of mixture_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of mixture_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of mixture_child.
    """
    molecular_weight: molecular_weight = molecular_weight
    """
    molecular_weight child of mixture_child.
    """
    mass_diffusivity: mass_diffusivity = mass_diffusivity
    """
    mass_diffusivity child of mixture_child.
    """
    thermal_diffusivity: thermal_diffusivity = thermal_diffusivity
    """
    thermal_diffusivity child of mixture_child.
    """
    formation_enthalpy: formation_enthalpy = formation_enthalpy
    """
    formation_enthalpy child of mixture_child.
    """
    formation_entropy: formation_entropy = formation_entropy
    """
    formation_entropy child of mixture_child.
    """
    characteristic_vibrational_temperature: characteristic_vibrational_temperature = characteristic_vibrational_temperature
    """
    characteristic_vibrational_temperature child of mixture_child.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of mixture_child.
    """
    lennard_jones_length: lennard_jones_length = lennard_jones_length
    """
    lennard_jones_length child of mixture_child.
    """
    lennard_jones_energy: lennard_jones_energy = lennard_jones_energy
    """
    lennard_jones_energy child of mixture_child.
    """
    thermal_accom_coefficient: thermal_accom_coefficient = thermal_accom_coefficient
    """
    thermal_accom_coefficient child of mixture_child.
    """
    velocity_accom_coefficient: velocity_accom_coefficient = velocity_accom_coefficient
    """
    velocity_accom_coefficient child of mixture_child.
    """
    absorption_coefficient: absorption_coefficient = absorption_coefficient
    """
    absorption_coefficient child of mixture_child.
    """
    scattering_coefficient: scattering_coefficient = scattering_coefficient
    """
    scattering_coefficient child of mixture_child.
    """
    scattering_phase_function: scattering_phase_function = scattering_phase_function
    """
    scattering_phase_function child of mixture_child.
    """
    therm_exp_coeff: therm_exp_coeff = therm_exp_coeff
    """
    therm_exp_coeff child of mixture_child.
    """
    premix_unburnt_density: premix_unburnt_density = premix_unburnt_density
    """
    premix_unburnt_density child of mixture_child.
    """
    premix_unburnt_temp: premix_unburnt_temp = premix_unburnt_temp
    """
    premix_unburnt_temp child of mixture_child.
    """
    premix_adiabatic_temp: premix_adiabatic_temp = premix_adiabatic_temp
    """
    premix_adiabatic_temp child of mixture_child.
    """
    premix_unburnt_cp: premix_unburnt_cp = premix_unburnt_cp
    """
    premix_unburnt_cp child of mixture_child.
    """
    premix_heat_trans_coeff: premix_heat_trans_coeff = premix_heat_trans_coeff
    """
    premix_heat_trans_coeff child of mixture_child.
    """
    premix_laminar_speed: premix_laminar_speed = premix_laminar_speed
    """
    premix_laminar_speed child of mixture_child.
    """
    premix_laminar_thickness: premix_laminar_thickness = premix_laminar_thickness
    """
    premix_laminar_thickness child of mixture_child.
    """
    premix_critical_strain: premix_critical_strain = premix_critical_strain
    """
    premix_critical_strain child of mixture_child.
    """
    premix_heat_of_comb: premix_heat_of_comb = premix_heat_of_comb
    """
    premix_heat_of_comb child of mixture_child.
    """
    premix_unburnt_fuel_mf: premix_unburnt_fuel_mf = premix_unburnt_fuel_mf
    """
    premix_unburnt_fuel_mf child of mixture_child.
    """
    refractive_index: refractive_index = refractive_index
    """
    refractive_index child of mixture_child.
    """
    latent_heat: latent_heat = latent_heat
    """
    latent_heat child of mixture_child.
    """
    thermophoretic_co: thermophoretic_co = thermophoretic_co
    """
    thermophoretic_co child of mixture_child.
    """
    vaporization_temperature: vaporization_temperature = vaporization_temperature
    """
    vaporization_temperature child of mixture_child.
    """
    boiling_point: boiling_point = boiling_point
    """
    boiling_point child of mixture_child.
    """
    volatile_fraction: volatile_fraction = volatile_fraction
    """
    volatile_fraction child of mixture_child.
    """
    binary_diffusivity: binary_diffusivity = binary_diffusivity
    """
    binary_diffusivity child of mixture_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure = diffusivity_reference_pressure
    """
    diffusivity_reference_pressure child of mixture_child.
    """
    vapor_pressure: vapor_pressure = vapor_pressure
    """
    vapor_pressure child of mixture_child.
    """
    degrees_of_freedom: degrees_of_freedom = degrees_of_freedom
    """
    degrees_of_freedom child of mixture_child.
    """
    emissivity: emissivity = emissivity
    """
    emissivity child of mixture_child.
    """
    scattering_factor: scattering_factor = scattering_factor
    """
    scattering_factor child of mixture_child.
    """
    heat_of_pyrolysis: heat_of_pyrolysis = heat_of_pyrolysis
    """
    heat_of_pyrolysis child of mixture_child.
    """
    swelling_coefficient: swelling_coefficient = swelling_coefficient
    """
    swelling_coefficient child of mixture_child.
    """
    burn_stoichiometry: burn_stoichiometry = burn_stoichiometry
    """
    burn_stoichiometry child of mixture_child.
    """
    combustible_fraction: combustible_fraction = combustible_fraction
    """
    combustible_fraction child of mixture_child.
    """
    burn_hreact: burn_hreact = burn_hreact
    """
    burn_hreact child of mixture_child.
    """
    burn_hreact_fraction: burn_hreact_fraction = burn_hreact_fraction
    """
    burn_hreact_fraction child of mixture_child.
    """
    devolatilization_model: devolatilization_model = devolatilization_model
    """
    devolatilization_model child of mixture_child.
    """
    combustion_model: combustion_model = combustion_model
    """
    combustion_model child of mixture_child.
    """
    averaging_coefficient_t: averaging_coefficient_t = averaging_coefficient_t
    """
    averaging_coefficient_t child of mixture_child.
    """
    averaging_coefficient_y: averaging_coefficient_y = averaging_coefficient_y
    """
    averaging_coefficient_y child of mixture_child.
    """
    vaporization_model: vaporization_model = vaporization_model
    """
    vaporization_model child of mixture_child.
    """
    thermolysis_model: thermolysis_model = thermolysis_model
    """
    thermolysis_model child of mixture_child.
    """
    melting_heat: melting_heat = melting_heat
    """
    melting_heat child of mixture_child.
    """
    tsolidus: tsolidus = tsolidus
    """
    tsolidus child of mixture_child.
    """
    tliqidus: tliqidus = tliqidus
    """
    tliqidus child of mixture_child.
    """
    tmelt: tmelt = tmelt
    """
    tmelt child of mixture_child.
    """
    liquidus_slope: liquidus_slope = liquidus_slope
    """
    liquidus_slope child of mixture_child.
    """
    partition_coeff: partition_coeff = partition_coeff
    """
    partition_coeff child of mixture_child.
    """
    eutectic_mf: eutectic_mf = eutectic_mf
    """
    eutectic_mf child of mixture_child.
    """
    eutectic_temp: eutectic_temp = eutectic_temp
    """
    eutectic_temp child of mixture_child.
    """
    solut_exp_coeff: solut_exp_coeff = solut_exp_coeff
    """
    solut_exp_coeff child of mixture_child.
    """
    solid_diffusion: solid_diffusion = solid_diffusion
    """
    solid_diffusion child of mixture_child.
    """
    uds_diffusivity: uds_diffusivity = uds_diffusivity
    """
    uds_diffusivity child of mixture_child.
    """
    dpm_surften: dpm_surften = dpm_surften
    """
    dpm_surften child of mixture_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of mixture_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of mixture_child.
    """
    lithium_diffusivity: lithium_diffusivity = lithium_diffusivity
    """
    lithium_diffusivity child of mixture_child.
    """
    magnetic_permeability: magnetic_permeability = magnetic_permeability
    """
    magnetic_permeability child of mixture_child.
    """
    charge_density: charge_density = charge_density
    """
    charge_density child of mixture_child.
    """
    charge: charge = charge
    """
    charge child of mixture_child.
    """
    speed_of_sound: speed_of_sound = speed_of_sound
    """
    speed_of_sound child of mixture_child.
    """
    species_phase: species_phase = species_phase
    """
    species_phase child of mixture_child.
    """
    vp_equilib: vp_equilib = vp_equilib
    """
    vp_equilib child of mixture_child.
    """
    critical_temperature: critical_temperature = critical_temperature
    """
    critical_temperature child of mixture_child.
    """
    critical_pressure: critical_pressure = critical_pressure
    """
    critical_pressure child of mixture_child.
    """
    critical_volume: critical_volume = critical_volume
    """
    critical_volume child of mixture_child.
    """
    acentric_factor: acentric_factor = acentric_factor
    """
    acentric_factor child of mixture_child.
    """
    saturation_pressure: saturation_pressure = saturation_pressure
    """
    saturation_pressure child of mixture_child.
    """
    struct_youngs_modulus: struct_youngs_modulus = struct_youngs_modulus
    """
    struct_youngs_modulus child of mixture_child.
    """
    struct_poisson_ratio: struct_poisson_ratio = struct_poisson_ratio
    """
    struct_poisson_ratio child of mixture_child.
    """
    struct_start_temperature: struct_start_temperature = struct_start_temperature
    """
    struct_start_temperature child of mixture_child.
    """
    struct_thermal_expansion: struct_thermal_expansion = struct_thermal_expansion
    """
    struct_thermal_expansion child of mixture_child.
    """
    atomic_number: atomic_number = atomic_number
    """
    atomic_number child of mixture_child.
    """
    struct_damping_alpha: struct_damping_alpha = struct_damping_alpha
    """
    struct_damping_alpha child of mixture_child.
    """
    struct_damping_beta: struct_damping_beta = struct_damping_beta
    """
    struct_damping_beta child of mixture_child.
    """
    mixture_species: mixture_species = mixture_species
    """
    mixture_species child of mixture_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .number_of_total_periods import number_of_total_periods
from .number_of_time_steps import number_of_time_steps
from .total_number_of_time_steps import total_number_of_time_steps
from .total_time import total_time
from .incremental_time import incremental_time
from .max_iteration_per_step import max_iteration_per_step
from .postprocess import postprocess
from .num_of_post_iter_per_timestep import num_of_post_iter_per_timestep
class dual_time_iterate(Command):
    """
    Perform unsteady iterations.
    
    Parameters
    ----------
        number_of_total_periods : int
            Set number of total periods.
        number_of_time_steps : int
            Set inceremtal number of Time steps.
        total_number_of_time_steps : int
            Set total number of Time steps.
        total_time : real
            Set Total Simulation Time.
        incremental_time : real
            Set Incremental Time.
        max_iteration_per_step : int
            Set Maximum Number of iterations per time step.
        postprocess : bool
            Enable/Disable Postprocess pollutant solution?.
        num_of_post_iter_per_timestep : int
            Set Number of post-processing iterations per time step.
    
    """

    fluent_name = "dual-time-iterate"

    argument_names = \
        ['number_of_total_periods', 'number_of_time_steps',
         'total_number_of_time_steps', 'total_time', 'incremental_time',
         'max_iteration_per_step', 'postprocess',
         'num_of_post_iter_per_timestep']

    number_of_total_periods: number_of_total_periods = number_of_total_periods
    """
    number_of_total_periods argument of dual_time_iterate.
    """
    number_of_time_steps: number_of_time_steps = number_of_time_steps
    """
    number_of_time_steps argument of dual_time_iterate.
    """
    total_number_of_time_steps: total_number_of_time_steps = total_number_of_time_steps
    """
    total_number_of_time_steps argument of dual_time_iterate.
    """
    total_time: total_time = total_time
    """
    total_time argument of dual_time_iterate.
    """
    incremental_time: incremental_time = incremental_time
    """
    incremental_time argument of dual_time_iterate.
    """
    max_iteration_per_step: max_iteration_per_step = max_iteration_per_step
    """
    max_iteration_per_step argument of dual_time_iterate.
    """
    postprocess: postprocess = postprocess
    """
    postprocess argument of dual_time_iterate.
    """
    num_of_post_iter_per_timestep: num_of_post_iter_per_timestep = num_of_post_iter_per_timestep
    """
    num_of_post_iter_per_timestep argument of dual_time_iterate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .create_1 import create_1
from .duplicate_1 import duplicate
from .load_case_data import load_case_data
from .delete_design_points import delete_design_points
from .save_journals import save_journals
from .clear_generated_data import clear_generated_data
from .update_current import update_current
from .update_all import update_all
from .update_selected import update_selected
from .design_points_child import design_points_child

class design_points(NamedObject[design_points_child], _CreatableNamedObjectMixin[design_points_child]):
    """
    'design_points' child.
    """

    fluent_name = "design-points"

    command_names = \
        ['create_1', 'duplicate', 'load_case_data', 'delete_design_points',
         'save_journals', 'clear_generated_data', 'update_current',
         'update_all', 'update_selected']

    create_1: create_1 = create_1
    """
    create_1 command of design_points.
    """
    duplicate: duplicate = duplicate
    """
    duplicate command of design_points.
    """
    load_case_data: load_case_data = load_case_data
    """
    load_case_data command of design_points.
    """
    delete_design_points: delete_design_points = delete_design_points
    """
    delete_design_points command of design_points.
    """
    save_journals: save_journals = save_journals
    """
    save_journals command of design_points.
    """
    clear_generated_data: clear_generated_data = clear_generated_data
    """
    clear_generated_data command of design_points.
    """
    update_current: update_current = update_current
    """
    update_current command of design_points.
    """
    update_all: update_all = update_all
    """
    update_all command of design_points.
    """
    update_selected: update_selected = update_selected
    """
    update_selected command of design_points.
    """
    child_object_type: design_points_child = design_points_child
    """
    child_object_type of design_points.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .first_rate import first_rate
from .second_rate import second_rate
class two_competing_rates(Group):
    """
    'two_competing_rates' child.
    """

    fluent_name = "two-competing-rates"

    child_names = \
        ['first_rate', 'second_rate']

    first_rate: first_rate = first_rate
    """
    first_rate child of two_competing_rates.
    """
    second_rate: second_rate = second_rate
    """
    second_rate child of two_competing_rates.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x_component import x_component
from .y_component import y_component
from .z_component import z_component
class direction_vector(Group):
    """
    'direction_vector' child.
    """

    fluent_name = "direction-vector"

    child_names = \
        ['x_component', 'y_component', 'z_component']

    x_component: x_component = x_component
    """
    x_component child of direction_vector.
    """
    y_component: y_component = y_component
    """
    y_component child of direction_vector.
    """
    z_component: z_component = z_component
    """
    z_component child of direction_vector.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .iter_count import iter_count
from .solution_stabilization_persistence import solution_stabilization_persistence
from .persistence_fixed_time_steps import persistence_fixed_time_steps
from .persistence_fixed_duration import persistence_fixed_duration
from .extrapolation_method import extrapolation_method
class parameters(Group):
    """
    'parameters' child.
    """

    fluent_name = "parameters"

    child_names = \
        ['iter_count', 'solution_stabilization_persistence',
         'persistence_fixed_time_steps', 'persistence_fixed_duration',
         'extrapolation_method']

    iter_count: iter_count = iter_count
    """
    iter_count child of parameters.
    """
    solution_stabilization_persistence: solution_stabilization_persistence = solution_stabilization_persistence
    """
    solution_stabilization_persistence child of parameters.
    """
    persistence_fixed_time_steps: persistence_fixed_time_steps = persistence_fixed_time_steps
    """
    persistence_fixed_time_steps child of parameters.
    """
    persistence_fixed_duration: persistence_fixed_duration = persistence_fixed_duration
    """
    persistence_fixed_duration child of parameters.
    """
    extrapolation_method: extrapolation_method = extrapolation_method
    """
    extrapolation_method child of parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .local_dt import local_dt
from .global_dt import global_dt
class advanced_options(Group):
    """
    'advanced_options' child.
    """

    fluent_name = "advanced-options"

    child_names = \
        ['local_dt', 'global_dt']

    local_dt: local_dt = local_dt
    """
    local_dt child of advanced_options.
    """
    global_dt: global_dt = global_dt
    """
    global_dt child of advanced_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .density import density
from .viscosity import viscosity
from .specific_heat import specific_heat
from .thermal_conductivity import thermal_conductivity
from .molecular_weight import molecular_weight
from .premix_laminar_speed import premix_laminar_speed
from .premix_critical_strain import premix_critical_strain
from .premix_unburnt_temp import premix_unburnt_temp
from .premix_unburnt_density import premix_unburnt_density
from .premix_heat_trans_coeff import premix_heat_trans_coeff
from .premix_heat_of_comb import premix_heat_of_comb
from .premix_unburnt_fuel_mf import premix_unburnt_fuel_mf
from .premix_adiabatic_temp import premix_adiabatic_temp
from .therm_exp_coeff import therm_exp_coeff
from .characteristic_vibrational_temperature import characteristic_vibrational_temperature
from .absorption_coefficient import absorption_coefficient
from .melting_heat import melting_heat
from .tsolidus import tsolidus
from .tliqidus import tliqidus
from .liquidus_slope import liquidus_slope
from .partition_coeff import partition_coeff
from .eutectic_mf import eutectic_mf
from .solid_diffusion import solid_diffusion
from .solut_exp_coeff import solut_exp_coeff
from .scattering_coefficient import scattering_coefficient
from .scattering_phase_function import scattering_phase_function
from .refractive_index import refractive_index
from .formation_entropy import formation_entropy
from .formation_enthalpy import formation_enthalpy
from .reference_temperature_1 import reference_temperature
from .lennard_jones_length import lennard_jones_length
from .lennard_jones_energy import lennard_jones_energy
from .thermal_accom_coefficient import thermal_accom_coefficient
from .velocity_accom_coefficient import velocity_accom_coefficient
from .degrees_of_freedom import degrees_of_freedom
from .uds_diffusivity import uds_diffusivity
from .electric_conductivity import electric_conductivity
from .dual_electric_conductivity import dual_electric_conductivity
from .lithium_diffusivity import lithium_diffusivity
from .magnetic_permeability import magnetic_permeability
from .speed_of_sound import speed_of_sound
from .critical_temperature import critical_temperature
from .critical_pressure import critical_pressure
from .critical_volume import critical_volume
from .acentric_factor import acentric_factor
from .latent_heat import latent_heat
from .saturation_pressure import saturation_pressure
from .vaporization_temperature import vaporization_temperature
from .charge import charge
class fluid_child(Group):
    """
    'child_object_type' of fluid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'viscosity', 'specific_heat', 'thermal_conductivity',
         'molecular_weight', 'premix_laminar_speed', 'premix_critical_strain',
         'premix_unburnt_temp', 'premix_unburnt_density',
         'premix_heat_trans_coeff', 'premix_heat_of_comb',
         'premix_unburnt_fuel_mf', 'premix_adiabatic_temp', 'therm_exp_coeff',
         'characteristic_vibrational_temperature', 'absorption_coefficient',
         'melting_heat', 'tsolidus', 'tliqidus', 'liquidus_slope',
         'partition_coeff', 'eutectic_mf', 'solid_diffusion',
         'solut_exp_coeff', 'scattering_coefficient',
         'scattering_phase_function', 'refractive_index', 'formation_entropy',
         'formation_enthalpy', 'reference_temperature',
         'lennard_jones_length', 'lennard_jones_energy',
         'thermal_accom_coefficient', 'velocity_accom_coefficient',
         'degrees_of_freedom', 'uds_diffusivity', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'magnetic_permeability', 'speed_of_sound', 'critical_temperature',
         'critical_pressure', 'critical_volume', 'acentric_factor',
         'latent_heat', 'saturation_pressure', 'vaporization_temperature',
         'charge']

    density: density = density
    """
    density child of fluid_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of fluid_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of fluid_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of fluid_child.
    """
    molecular_weight: molecular_weight = molecular_weight
    """
    molecular_weight child of fluid_child.
    """
    premix_laminar_speed: premix_laminar_speed = premix_laminar_speed
    """
    premix_laminar_speed child of fluid_child.
    """
    premix_critical_strain: premix_critical_strain = premix_critical_strain
    """
    premix_critical_strain child of fluid_child.
    """
    premix_unburnt_temp: premix_unburnt_temp = premix_unburnt_temp
    """
    premix_unburnt_temp child of fluid_child.
    """
    premix_unburnt_density: premix_unburnt_density = premix_unburnt_density
    """
    premix_unburnt_density child of fluid_child.
    """
    premix_heat_trans_coeff: premix_heat_trans_coeff = premix_heat_trans_coeff
    """
    premix_heat_trans_coeff child of fluid_child.
    """
    premix_heat_of_comb: premix_heat_of_comb = premix_heat_of_comb
    """
    premix_heat_of_comb child of fluid_child.
    """
    premix_unburnt_fuel_mf: premix_unburnt_fuel_mf = premix_unburnt_fuel_mf
    """
    premix_unburnt_fuel_mf child of fluid_child.
    """
    premix_adiabatic_temp: premix_adiabatic_temp = premix_adiabatic_temp
    """
    premix_adiabatic_temp child of fluid_child.
    """
    therm_exp_coeff: therm_exp_coeff = therm_exp_coeff
    """
    therm_exp_coeff child of fluid_child.
    """
    characteristic_vibrational_temperature: characteristic_vibrational_temperature = characteristic_vibrational_temperature
    """
    characteristic_vibrational_temperature child of fluid_child.
    """
    absorption_coefficient: absorption_coefficient = absorption_coefficient
    """
    absorption_coefficient child of fluid_child.
    """
    melting_heat: melting_heat = melting_heat
    """
    melting_heat child of fluid_child.
    """
    tsolidus: tsolidus = tsolidus
    """
    tsolidus child of fluid_child.
    """
    tliqidus: tliqidus = tliqidus
    """
    tliqidus child of fluid_child.
    """
    liquidus_slope: liquidus_slope = liquidus_slope
    """
    liquidus_slope child of fluid_child.
    """
    partition_coeff: partition_coeff = partition_coeff
    """
    partition_coeff child of fluid_child.
    """
    eutectic_mf: eutectic_mf = eutectic_mf
    """
    eutectic_mf child of fluid_child.
    """
    solid_diffusion: solid_diffusion = solid_diffusion
    """
    solid_diffusion child of fluid_child.
    """
    solut_exp_coeff: solut_exp_coeff = solut_exp_coeff
    """
    solut_exp_coeff child of fluid_child.
    """
    scattering_coefficient: scattering_coefficient = scattering_coefficient
    """
    scattering_coefficient child of fluid_child.
    """
    scattering_phase_function: scattering_phase_function = scattering_phase_function
    """
    scattering_phase_function child of fluid_child.
    """
    refractive_index: refractive_index = refractive_index
    """
    refractive_index child of fluid_child.
    """
    formation_entropy: formation_entropy = formation_entropy
    """
    formation_entropy child of fluid_child.
    """
    formation_enthalpy: formation_enthalpy = formation_enthalpy
    """
    formation_enthalpy child of fluid_child.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of fluid_child.
    """
    lennard_jones_length: lennard_jones_length = lennard_jones_length
    """
    lennard_jones_length child of fluid_child.
    """
    lennard_jones_energy: lennard_jones_energy = lennard_jones_energy
    """
    lennard_jones_energy child of fluid_child.
    """
    thermal_accom_coefficient: thermal_accom_coefficient = thermal_accom_coefficient
    """
    thermal_accom_coefficient child of fluid_child.
    """
    velocity_accom_coefficient: velocity_accom_coefficient = velocity_accom_coefficient
    """
    velocity_accom_coefficient child of fluid_child.
    """
    degrees_of_freedom: degrees_of_freedom = degrees_of_freedom
    """
    degrees_of_freedom child of fluid_child.
    """
    uds_diffusivity: uds_diffusivity = uds_diffusivity
    """
    uds_diffusivity child of fluid_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of fluid_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of fluid_child.
    """
    lithium_diffusivity: lithium_diffusivity = lithium_diffusivity
    """
    lithium_diffusivity child of fluid_child.
    """
    magnetic_permeability: magnetic_permeability = magnetic_permeability
    """
    magnetic_permeability child of fluid_child.
    """
    speed_of_sound: speed_of_sound = speed_of_sound
    """
    speed_of_sound child of fluid_child.
    """
    critical_temperature: critical_temperature = critical_temperature
    """
    critical_temperature child of fluid_child.
    """
    critical_pressure: critical_pressure = critical_pressure
    """
    critical_pressure child of fluid_child.
    """
    critical_volume: critical_volume = critical_volume
    """
    critical_volume child of fluid_child.
    """
    acentric_factor: acentric_factor = acentric_factor
    """
    acentric_factor child of fluid_child.
    """
    latent_heat: latent_heat = latent_heat
    """
    latent_heat child of fluid_child.
    """
    saturation_pressure: saturation_pressure = saturation_pressure
    """
    saturation_pressure child of fluid_child.
    """
    vaporization_temperature: vaporization_temperature = vaporization_temperature
    """
    vaporization_temperature child of fluid_child.
    """
    charge: charge = charge
    """
    charge child of fluid_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .scalar_parameters import scalar_parameters
from .coupled_parameters import coupled_parameters
from .flexible_cycle_paramters import flexible_cycle_paramters
from .options_1 import options
class algebric_mg_controls(Group):
    """
    'algebric_mg_controls' child.
    """

    fluent_name = "algebric-mg-controls"

    child_names = \
        ['scalar_parameters', 'coupled_parameters',
         'flexible_cycle_paramters', 'options']

    scalar_parameters: scalar_parameters = scalar_parameters
    """
    scalar_parameters child of algebric_mg_controls.
    """
    coupled_parameters: coupled_parameters = coupled_parameters
    """
    coupled_parameters child of algebric_mg_controls.
    """
    flexible_cycle_paramters: flexible_cycle_paramters = flexible_cycle_paramters
    """
    flexible_cycle_paramters child of algebric_mg_controls.
    """
    options: options = options
    """
    options child of algebric_mg_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .distance_option import distance_option
from .boundary_list import boundary_list
from .create_volume_surface import create_volume_surface
class boundary(Group):
    """
    'boundary' child.
    """

    fluent_name = "boundary"

    child_names = \
        ['distance_option', 'boundary_list', 'create_volume_surface']

    distance_option: distance_option = distance_option
    """
    distance_option child of boundary.
    """
    boundary_list: boundary_list = boundary_list
    """
    boundary_list child of boundary.
    """
    create_volume_surface: create_volume_surface = create_volume_surface
    """
    create_volume_surface child of boundary.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .archive_name import archive_name
class archive(Command):
    """
    Archive Project.
    
    Parameters
    ----------
        archive_name : str
            'archive_name' child.
    
    """

    fluent_name = "archive"

    argument_names = \
        ['archive_name']

    archive_name: archive_name = archive_name
    """
    archive_name argument of archive.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enabled_2 import enabled
from .color import color
class constant_color(Group):
    """
    'constant_color' child.
    """

    fluent_name = "constant-color"

    child_names = \
        ['enabled', 'color']

    enabled: enabled = enabled
    """
    enabled child of constant_color.
    """
    color: color = color
    """
    color child of constant_color.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mixture_child import mixture_child

class particle_mixture(NamedObject[mixture_child], _CreatableNamedObjectMixin[mixture_child]):
    """
    'particle_mixture' child.
    """

    fluent_name = "particle-mixture"

    child_object_type: mixture_child = mixture_child
    """
    child_object_type of particle_mixture.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .boundary_treatment import boundary_treatment
from .extended_boundary_treatment import extended_boundary_treatment
class nb_gradient_dbns(Group):
    """
    'nb_gradient_dbns' child.
    """

    fluent_name = "nb-gradient-dbns"

    child_names = \
        ['boundary_treatment', 'extended_boundary_treatment']

    boundary_treatment: boundary_treatment = boundary_treatment
    """
    boundary_treatment child of nb_gradient_dbns.
    """
    extended_boundary_treatment: extended_boundary_treatment = extended_boundary_treatment
    """
    extended_boundary_treatment child of nb_gradient_dbns.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .global_range import global_range
class auto_range_on(Group):
    """
    'auto_range_on' child.
    """

    fluent_name = "auto-range-on"

    child_names = \
        ['global_range']

    global_range: global_range = global_range
    """
    global_range child of auto_range_on.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class random_surface_inj(Boolean):
    """
    'random_surface_inj' child.
    """

    fluent_name = "random-surface-inj?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .outlet_vent_child import outlet_vent_child

class outlet_vent(NamedObject[outlet_vent_child], _NonCreatableNamedObjectMixin[outlet_vent_child]):
    """
    'outlet_vent' child.
    """

    fluent_name = "outlet-vent"

    child_object_type: outlet_vent_child = outlet_vent_child
    """
    child_object_type of outlet_vent.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .graphics import graphics
from .surfaces_1 import surfaces
class results(Group):
    """
    'results' child.
    """

    fluent_name = "results"

    child_names = \
        ['graphics', 'surfaces']

    graphics: graphics = graphics
    """
    graphics child of results.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of results.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .yplus_1 import yplus
from .ystar import ystar
class option(Group):
    """
    'option' child.
    """

    fluent_name = "option"

    child_names = \
        ['option', 'yplus', 'ystar']

    option: option = option
    """
    option child of option.
    """
    yplus: yplus = yplus
    """
    yplus child of option.
    """
    ystar: ystar = ystar
    """
    ystar child of option.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .background_1 import background
from .color_filter import color_filter
from .foreground_1 import foreground
from .on import on
from .pixel_size import pixel_size
class video(Group):
    """
    Enter the video window options menu.
    """

    fluent_name = "video"

    child_names = \
        ['background', 'color_filter', 'foreground', 'on', 'pixel_size']

    background: background = background
    """
    background child of video.
    """
    color_filter: color_filter = color_filter
    """
    color_filter child of video.
    """
    foreground: foreground = foreground
    """
    foreground child of video.
    """
    on: on = on
    """
    on child of video.
    """
    pixel_size: pixel_size = pixel_size
    """
    pixel_size child of video.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .blade_pitch_collective import blade_pitch_collective
from .blade_pitch_cyclic_sin import blade_pitch_cyclic_sin
from .blade_pitch_cyclic_cos import blade_pitch_cyclic_cos
class blade_pitch_angles(Group):
    """
    Menu to define the rotor pitch and flapping angles.
    
     - blade-pitch-collective    : , 
     - blade-pitch-cyclic-sin    : , 
     - blade-pitch-cyclic-cos    : , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "blade-pitch-angles"

    child_names = \
        ['blade_pitch_collective', 'blade_pitch_cyclic_sin',
         'blade_pitch_cyclic_cos']

    blade_pitch_collective: blade_pitch_collective = blade_pitch_collective
    """
    blade_pitch_collective child of blade_pitch_angles.
    """
    blade_pitch_cyclic_sin: blade_pitch_cyclic_sin = blade_pitch_cyclic_sin
    """
    blade_pitch_cyclic_sin child of blade_pitch_angles.
    """
    blade_pitch_cyclic_cos: blade_pitch_cyclic_cos = blade_pitch_cyclic_cos
    """
    blade_pitch_cyclic_cos child of blade_pitch_angles.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mesh import mesh
from .surface import surface
from .volume import volume
from .force import force
from .lift import lift
from .drag import drag
from .moment import moment
from .flux import flux
from .injection import injection
from .user_defined import user_defined
from .aeromechanics import aeromechanics
from .expression import expression
from .custom import custom
from .compute_2 import compute
class report_definitions(Group):
    """
    'report_definitions' child.
    """

    fluent_name = "report-definitions"

    child_names = \
        ['mesh', 'surface', 'volume', 'force', 'lift', 'drag', 'moment',
         'flux', 'injection', 'user_defined', 'aeromechanics', 'expression',
         'custom']

    mesh: mesh = mesh
    """
    mesh child of report_definitions.
    """
    surface: surface = surface
    """
    surface child of report_definitions.
    """
    volume: volume = volume
    """
    volume child of report_definitions.
    """
    force: force = force
    """
    force child of report_definitions.
    """
    lift: lift = lift
    """
    lift child of report_definitions.
    """
    drag: drag = drag
    """
    drag child of report_definitions.
    """
    moment: moment = moment
    """
    moment child of report_definitions.
    """
    flux: flux = flux
    """
    flux child of report_definitions.
    """
    injection: injection = injection
    """
    injection child of report_definitions.
    """
    user_defined: user_defined = user_defined
    """
    user_defined child of report_definitions.
    """
    aeromechanics: aeromechanics = aeromechanics
    """
    aeromechanics child of report_definitions.
    """
    expression: expression = expression
    """
    expression child of report_definitions.
    """
    custom: custom = custom
    """
    custom child of report_definitions.
    """
    command_names = \
        ['compute']

    compute: compute = compute
    """
    compute command of report_definitions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .write_data import write_data
from .capture_simulation_report_data import capture_simulation_report_data
class create_1(Command):
    """
    Add new Design Point.
    
    Parameters
    ----------
        write_data : bool
            'write_data' child.
        capture_simulation_report_data : bool
            'capture_simulation_report_data' child.
    
    """

    fluent_name = "create"

    argument_names = \
        ['write_data', 'capture_simulation_report_data']

    write_data: write_data = write_data
    """
    write_data argument of create_1.
    """
    capture_simulation_report_data: capture_simulation_report_data = capture_simulation_report_data
    """
    capture_simulation_report_data argument of create_1.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class all_bndry_zones(Boolean):
    """
    Select all the boundary/interior zones.
    """

    fluent_name = "all-bndry-zones?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class check_verbosity(Integer):
    """
    Set verbosity output of parallel check. Higher verbosity corresponds to more detailed information.
    """

    fluent_name = "check-verbosity"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .border_4 import border
from .bottom_4 import bottom
from .left_4 import left
from .right_5 import right
from .top_4 import top
from .visible_5 import visible
class xy(Group):
    """
    Enter the X-Y plot window options menu.
    """

    fluent_name = "xy"

    child_names = \
        ['border', 'bottom', 'left', 'right', 'top', 'visible']

    border: border = border
    """
    border child of xy.
    """
    bottom: bottom = bottom
    """
    bottom child of xy.
    """
    left: left = left
    """
    left child of xy.
    """
    right: right = right
    """
    right child of xy.
    """
    top: top = top
    """
    top child of xy.
    """
    visible: visible = visible
    """
    visible child of xy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option import option
from .constant import constant
from .boussinesq import boussinesq
from .coefficients import coefficients
from .number_of_coefficients import number_of_coefficients
from .piecewise_polynomial import piecewise_polynomial
from .nasa_9_piecewise_polynomial import nasa_9_piecewise_polynomial
from .piecewise_linear import piecewise_linear
from .anisotropic import anisotropic
from .orthotropic import orthotropic
from .var_class import var_class
class vaporization_model(Group):
    """
    'vaporization_model' child.
    """

    fluent_name = "vaporization-model"

    child_names = \
        ['option', 'constant', 'boussinesq', 'coefficients',
         'number_of_coefficients', 'piecewise_polynomial',
         'nasa_9_piecewise_polynomial', 'piecewise_linear', 'anisotropic',
         'orthotropic', 'var_class']

    option: option = option
    """
    option child of vaporization_model.
    """
    constant: constant = constant
    """
    constant child of vaporization_model.
    """
    boussinesq: boussinesq = boussinesq
    """
    boussinesq child of vaporization_model.
    """
    coefficients: coefficients = coefficients
    """
    coefficients child of vaporization_model.
    """
    number_of_coefficients: number_of_coefficients = number_of_coefficients
    """
    number_of_coefficients child of vaporization_model.
    """
    piecewise_polynomial: piecewise_polynomial = piecewise_polynomial
    """
    piecewise_polynomial child of vaporization_model.
    """
    nasa_9_piecewise_polynomial: nasa_9_piecewise_polynomial = nasa_9_piecewise_polynomial
    """
    nasa_9_piecewise_polynomial child of vaporization_model.
    """
    piecewise_linear: piecewise_linear = piecewise_linear
    """
    piecewise_linear child of vaporization_model.
    """
    anisotropic: anisotropic = anisotropic
    """
    anisotropic child of vaporization_model.
    """
    orthotropic: orthotropic = orthotropic
    """
    orthotropic child of vaporization_model.
    """
    var_class: var_class = var_class
    """
    var_class child of vaporization_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class high_order_rc(Boolean):
    """
    Use low order velocity interpolation in flux calculation.
    """

    fluent_name = "high-order-rc?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .gray_band_coefficients import gray_band_coefficients
class refractive_index(Group):
    """
    'refractive_index' child.
    """

    fluent_name = "refractive-index"

    child_names = \
        ['option', 'value', 'gray_band_coefficients']

    option: option = option
    """
    option child of refractive_index.
    """
    value: value = value
    """
    value child of refractive_index.
    """
    gray_band_coefficients: gray_band_coefficients = gray_band_coefficients
    """
    gray_band_coefficients child of refractive_index.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .porous_media import porous_media
from .compressible_flow import compressible_flow
from .boiling_parameters import boiling_parameters
from .viscous_flow import viscous_flow
from .heat_mass_transfer import heat_mass_transfer
from .advanced_stability_controls import advanced_stability_controls
from .default_controls import default_controls
from .face_pressure_controls import face_pressure_controls
from .solution_stabilization_1 import solution_stabilization
class multiphase_numerics(Group):
    """
    Enter the multiphase numerics options menu.
    """

    fluent_name = "multiphase-numerics"

    child_names = \
        ['porous_media', 'compressible_flow', 'boiling_parameters',
         'viscous_flow', 'heat_mass_transfer', 'advanced_stability_controls',
         'default_controls', 'face_pressure_controls',
         'solution_stabilization']

    porous_media: porous_media = porous_media
    """
    porous_media child of multiphase_numerics.
    """
    compressible_flow: compressible_flow = compressible_flow
    """
    compressible_flow child of multiphase_numerics.
    """
    boiling_parameters: boiling_parameters = boiling_parameters
    """
    boiling_parameters child of multiphase_numerics.
    """
    viscous_flow: viscous_flow = viscous_flow
    """
    viscous_flow child of multiphase_numerics.
    """
    heat_mass_transfer: heat_mass_transfer = heat_mass_transfer
    """
    heat_mass_transfer child of multiphase_numerics.
    """
    advanced_stability_controls: advanced_stability_controls = advanced_stability_controls
    """
    advanced_stability_controls child of multiphase_numerics.
    """
    default_controls: default_controls = default_controls
    """
    default_controls child of multiphase_numerics.
    """
    face_pressure_controls: face_pressure_controls = face_pressure_controls
    """
    face_pressure_controls child of multiphase_numerics.
    """
    solution_stabilization: solution_stabilization = solution_stabilization
    """
    solution_stabilization child of multiphase_numerics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class persistence_fixed_duration(Real):
    """
    Specify fixed time for solution stabilization persistence after trigger.
    """

    fluent_name = "persistence-fixed-duration"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .input_parameters import input_parameters
from .output_parameters import output_parameters
from .write_data_1 import write_data
from .capture_simulation_report_data_1 import capture_simulation_report_data
class design_points_child(Group):
    """
    'child_object_type' of design_points.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['input_parameters', 'output_parameters', 'write_data',
         'capture_simulation_report_data']

    input_parameters: input_parameters = input_parameters
    """
    input_parameters child of design_points_child.
    """
    output_parameters: output_parameters = output_parameters
    """
    output_parameters child of design_points_child.
    """
    write_data: write_data = write_data
    """
    write_data child of design_points_child.
    """
    capture_simulation_report_data: capture_simulation_report_data = capture_simulation_report_data
    """
    capture_simulation_report_data child of design_points_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .principal_axes import principal_axes
from .principal_values import principal_values
from .conductivity import conductivity
class principal_axes_values(Group):
    """
    'principal_axes_values' child.
    """

    fluent_name = "principal-axes-values"

    child_names = \
        ['principal_axes', 'principal_values', 'conductivity']

    principal_axes: principal_axes = principal_axes
    """
    principal_axes child of principal_axes_values.
    """
    principal_values: principal_values = principal_values
    """
    principal_values child of principal_axes_values.
    """
    conductivity: conductivity = conductivity
    """
    conductivity child of principal_axes_values.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
class molecular_weight(Group):
    """
    'molecular_weight' child.
    """

    fluent_name = "molecular-weight"

    child_names = \
        ['option', 'value']

    option: option = option
    """
    option child of molecular_weight.
    """
    value: value = value
    """
    value child of molecular_weight.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .averaged_turbulent_parameters import averaged_turbulent_parameters
from .turbulent_intensity_1 import turbulent_intensity
from .viscosity_ratio_1 import viscosity_ratio
class turbulent_setting(Group):
    """
    Enter the turbulent settings menu.
    """

    fluent_name = "turbulent-setting"

    child_names = \
        ['averaged_turbulent_parameters', 'turbulent_intensity',
         'viscosity_ratio']

    averaged_turbulent_parameters: averaged_turbulent_parameters = averaged_turbulent_parameters
    """
    averaged_turbulent_parameters child of turbulent_setting.
    """
    turbulent_intensity: turbulent_intensity = turbulent_intensity
    """
    turbulent_intensity child of turbulent_setting.
    """
    viscosity_ratio: viscosity_ratio = viscosity_ratio
    """
    viscosity_ratio child of turbulent_setting.
    """
